<?php
/**
 * admania: Customizer
 *
 * @package WordPress
 * @subpackage admania
 * @since 1.0
 */
 
if ( is_admin() && defined( 'DOING_AJAX' ) && DOING_AJAX && ! is_customize_preview() ) {
	return;
}

/**
 * Add refresh support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
 
if(! function_exists( 'admania_customize_register' )):
 
function admania_customize_register( $wp_customize ) {
	
	
	$wp_customize->get_setting( 'blogname' )->transport   = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'background_color' )->transport  = 'postMessage';
	
	$wp_customize->selective_refresh->add_partial(
		'blogname', array(
			'selector'        => '.admania-headermidmd .admania-sitetitle a',
			'render_callback' => 'admania_customize_partial_blogname',
		)
	);
	
	$wp_customize->selective_refresh->add_partial(
		'blogdescription', array(
			'selector'        => '.admania-headermidmd p',
			'render_callback' => 'admania_customize_partial_blogdescription',
		)
	);
	
	$wp_customize->selective_refresh->add_partial(
		'background_color', array(            		
			'render_callback' => 'admania_customize_partial_background_color',
		)
	);
	
	$wp_customize->add_setting('admania_header_titledescription_setting',array(
	  'capability' => 'edit_theme_options',      
      'transport' => 'refresh',
      'sanitize_callback' => 'absint'	  
	));
	
	$wp_customize->add_control('admania_header_titledescription_control',array(
	  'type' => 'checkbox',
	  'section' => 'title_tagline',
	  'label' => esc_html__('Disable the Title and Description','ad-mania'),
	  'settings' => 'admania_header_titledescription_setting',
	  'description' => esc_html__('Here, you can Disable the header logo title description','ad-mania'),
	));
	
		
	/**
	* Add panel,section,setting,control for the theme options.
	*/
	
	$wp_customize->add_panel('admania-panel-id',array(
		'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'title' => esc_html__( 'Admania Settings', 'ad-mania' ),
	    'description' => esc_html__( 'This panel allows you to set up our theme settings.', 'ad-mania' ),
	));
			
	// Text transfrom choices
	
	$admania_texttransform_list = array('capitalize'=> esc_html__('Capitalize','ad-mania'),'lowercase'=>esc_html__('Lowercase','ad-mania'),'uppercase'=>esc_html__('Uppercase','ad-mania'),'none'=>esc_html__('None','ad-mania'));
	
	// post content link type choices
	
	$admania_post_link_types = array('none'=> esc_html__('None','ad-mania'),'overline'=> esc_html__('Overline','ad-mania'),'underline'=>esc_html__('Underline','ad-mania'));

    if ( class_exists( 'Woocommerce' ) ) {

	$admania_product_args = array(
			 'taxonomy'     => 'product_cat',
			 'orderby'      => 'name',		 
			 'show_count'   => 0,
			 'pad_counts'   => 0,
			 'hierarchical' => 1,
			 'title_li'     => '',
			 'hide_empty'   => 0
	);
	
	$admania_product_get_cattypes = get_categories($admania_product_args);
	
	$admania_product_cattypes = array();
	$j = 0;
	
	foreach($admania_product_get_cattypes as $admania_product_cat) {
		
		if( $j == 0 ){
			$admania_product_catdefault = $admania_product_cat->term_id;
			$j++;
		}
		
		$admania_product_cattypes[$admania_product_cat->term_id] = $admania_product_cat->slug;
	}
	
    }
	
    $admania_args = array(
		'orderby' => 'name',
		'order' => 'ASC'
	);
  
	$admania_getcats = get_categories($admania_args);
	
	$admania_cats = array();
	$i = 0;
	
	foreach($admania_getcats as $admania_cat) {
		
		if( $i == 0 ){
			$admania_catdefault = $admania_cat->term_id;
			$i++;
		}
		
		$admania_cats[$admania_cat->term_id] = $admania_cat->slug;
	}
    
	$wp_customize->add_section('admania-general-settings',array(
	   
	   'title' => esc_html__('General Settings','ad-mania'), 
	   'priority' => 11,
       'panel' => 'admania-panel-id'       
	   
	));	
		
	//  Theme option exapnding Section,Setting,Control
	
	$wp_customize->add_setting('admania-themeoption-expand1',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_layout_width_option_expand_custom_control($wp_customize,'admania-themeoption-expand1',array(
        'section' => 'admania-general-settings', 		
		'setting' => 'admania-themeoption-expand1',		
	)));
		
	// Add Layout Width Section, Setting, Control.
		
	$wp_customize->add_setting('wholelayoutwidth',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh', 
		'default' => 1200,
        'sanitize_callback' => 'absint', // The hue is stored as a positive integer.		
	));

	$wp_customize->add_control('admania_layout_width_control',array(
        
		'type' => 'text',		
		'section' => 'admania-general-settings', 
		'label' => esc_html__('Enter site container width','ad-mania'),
		'settings' => 'wholelayoutwidth',
		
	));
	
	$wp_customize->add_setting('admania-themeoption-expand49',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_header_search_expand_custom_control($wp_customize,'admania-themeoption-expand49',array(
        'section' => 'admania-general-settings', 		
		'setting' => 'admania-themeoption-expand49',		
	)));	
				
	// Add theme front-end responsive mode Section, Setting, Control.
		
	$wp_customize->add_setting('admania_hdrsrch',array(
	
	   'capability' => 'edit_theme_options',
	   'transport' => 'refresh',
	   'default' => 0,
	   'sanitize_callback' => 'absint',
	
	));
	
	$wp_customize->add_control('admania_header_search_control',array(
	  
	  'type' => 'checkbox',
	  'section' => 'admania-general-settings',
	  'label' => esc_html__('Hide header search','ad-mania'),
	  'settings' => 'admania_hdrsrch',
	  
	));
	
	$wp_customize->selective_refresh->add_partial('admania_hdrsrch', array(
       'selector' => '.admania-headersearchform', // header search div class selector name
    ));
	
	//  Theme option exapnding Section,Setting,Control
	
	$wp_customize->add_setting('admania-themeoption-expand2',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_header_social_expand_custom_control($wp_customize,'admania-themeoption-expand2',array(
        'section' => 'admania-general-settings', 		
		'setting' => 'admania-themeoption-expand2',		
	)));		
	
	// Add Header Social Networks Section, Setting, Control.
	
	$wp_customize->add_setting('admania_hdfacebook',array(
        'capability' => 'edit_theme_options',
		'transport' => 'postMessage',
        'sanitize_callback' => 'esc_url',
	));

	$wp_customize->add_control('admania_header_social_fb_control',array(
        'type' => 'url',
		'section' => 'admania-general-settings', 
		'label' => esc_html__('Facebook Url ','ad-mania'),
		'settings' => 'admania_hdfacebook',
	));
	
	$wp_customize->selective_refresh->add_partial('admania_hdfacebook', array(
       'selector' => '.admania-siteheader .admania_socialiconfb', // facebook div class selector name
    ));
			
	$wp_customize->add_setting('admania_hdtwitter',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_url',
	));
	
	$wp_customize->add_control('admania_header_social_twitter_control',array(
        'type' => 'url',
		'section' => 'admania-general-settings', 
		'label' => esc_html__('Twitter url ','ad-mania'),
		'settings' => 'admania_hdtwitter',
	));
	
	$wp_customize->selective_refresh->add_partial('admania_hdtwitter', array(
       'selector' => '.admania-siteheader .admania_socialicontwt', // facebook div class selector name
    ));
			
	$wp_customize->add_setting('admania_hdgoogleplus',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_url',
	));
	
	$wp_customize->add_control('admania_header_social_gplus_control',array(
        'type' => 'url',
		'section' => 'admania-general-settings', 
		'label' => esc_html__('Googleplus url ','ad-mania'),
		'settings' => 'admania_hdgoogleplus',
		
	));
	
	$wp_customize->selective_refresh->add_partial('admania_hdgoogleplus', array(
       'selector' => '.admania-siteheader .admania_socialicongle', // facebook div class selector name
    ));
	
	$wp_customize->add_setting('admania_hdlinkedin',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_url',
	));
	
	$wp_customize->add_control('admania_header_social_linkedin_control',array(
        'type' => 'url',
		'section' => 'admania-general-settings', 
		'label' => esc_html__('Linkedin url ','ad-mania'),
		'settings' => 'admania_hdlinkedin',
	)); 
	
	$wp_customize->selective_refresh->add_partial('admania_hdlinkedin', array(
       'selector' => '.admania-siteheader .admania_socialiconlnk', // facebook div class selector name
    ));
	
	$wp_customize->add_setting('admania_hdyoutube',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_url',
	));
	
	$wp_customize->add_control('admania_header_social_youtube_control',array(
        'type' => 'url',
		'section' => 'admania-general-settings', 
		'label' => esc_html__('youtube url ','ad-mania'),
		'settings' => 'admania_hdyoutube',
	)); 
	
	$wp_customize->selective_refresh->add_partial('admania_hdyoutube', array(
       'selector' => '.admania-siteheader .admania-socialiconyt', // facebook div class selector name
    ));
	
	$wp_customize->add_setting('admania_hdinstagram',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_url',
	));
	
	$wp_customize->add_control('admania_header_social_instagram_control',array(
        'type' => 'url',
		'section' => 'admania-general-settings', 
		'label' => esc_html__('instagram url ','ad-mania'),
		'settings' => 'admania_hdinstagram',
	)); 
	
	$wp_customize->selective_refresh->add_partial('admania_hdinstagram', array(
       'selector' => '.admania-siteheader .admania_socialiconins', // facebook div class selector name
    ));
	
	$wp_customize->add_setting('admania_hdpinterest',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_url',
	));
	
	$wp_customize->add_control('admania_header_social_pinterest_control',array(
        'type' => 'url',
		'section' => 'admania-general-settings', 
		'label' => esc_html__('Pinterest url ','ad-mania'),
		'settings' => 'admania_hdpinterest',
	));    
		
	$wp_customize->selective_refresh->add_partial('admania_hdpinterest', array(
       'selector' => '.admania-siteheader .admania-socialiconpin', // facebook div class selector name
    ));
	
	$wp_customize->add_setting('admania_hdrss',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_url',
	));
	
	$wp_customize->add_control('admania_header_social_rssfeed_control',array(
        'type' => 'url',
		'section' => 'admania-general-settings', 
		'label' => esc_html__('Rssfeed url ','ad-mania'),
		'settings' => 'admania_hdrss',
	)); 
	
	$wp_customize->selective_refresh->add_partial('admania_hdrss', array(
       'selector' => '.admania-siteheader .admania-socialiconrss', // facebook div class selector name
    ));
	
	$wp_customize->add_setting('admania_hdtg',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_url',
	));
	
	$wp_customize->add_control('admania_header_social_telegram_control',array(
        'type' => 'url',
		'section' => 'admania-general-settings', 
		'label' => esc_html__('Telegram url ','ad-mania'),
		'settings' => 'admania_hdtg',
	)); 
	
	$wp_customize->selective_refresh->add_partial('admania_hdtg', array(
       'selector' => '.admania-siteheader .admania_socialicontg', // facebook div class selector name
    ));
	
	$wp_customize->add_setting('admania-themeoption-expand6',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_latest_post_title_expand_custom_control($wp_customize,'admania-themeoption-expand6',array(
        'section' => 'admania-general-settings', 		
		'setting' => 'admania-themeoption-expand6',		
	)));		
	
	// Add Latest Post Title Section, Setting, Control.
	
	$wp_customize->add_setting('admania_latest_post_title_setting',array(
        'capability' => 'edit_theme_options',
		'transport' => 'postMessage',
        'sanitize_callback' => 'esc_html',
	));

	$wp_customize->add_control('admania_latest_post_title_control',array(
        'type' => 'text',
		'section' => 'admania-general-settings', 
		'label' => esc_html__('Latest Post Title','ad-mania'),
		'settings' => 'admania_latest_post_title_setting',
	));
	
	$wp_customize->selective_refresh->add_partial('admania_latest_post_title_setting', array(
       'selector' => '.admania-editor-pickers-title', // facebook div class selector name
       'render_callback' => 'admania_latest_post_title_text'  
	));
	
	$wp_customize->add_setting('admania-themeoption-expand7',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_header_script_expand_custom_control($wp_customize,'admania-themeoption-expand7',array(
        'section' => 'admania-general-settings', 		
		'setting' => 'admania-themeoption-expand7',		
	)));		
	
	// Add Header Script Code Section, Setting, Control.
	
	$wp_customize->add_setting('admania_header_script',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_textarea',
	));

	$wp_customize->add_control('admania_header_script_control',array(
        'type' => 'textarea',
		'section' => 'admania-general-settings', 
		'label' => esc_html__('Header Script Code','ad-mania'),
		'settings' => 'admania_header_script',
	));
	
	$wp_customize->add_setting('admania-themeoption-expand8',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_footer_script_expand_custom_control($wp_customize,'admania-themeoption-expand8',array(
        'section' => 'admania-general-settings', 		
		'setting' => 'admania-themeoption-expand8',		
	)));		
	
	// Add Footer Script Code Section, Setting, Control.
	
	$wp_customize->add_setting('admania_footer_script',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_textarea',
	));

	$wp_customize->add_control('admania_footer_script_control',array(
        'type' => 'textarea',
		'section' => 'admania-general-settings', 
		'label' => esc_html__('Footer Script Code','ad-mania'),
		'settings' => 'admania_footer_script',
	));
	
	$wp_customize->add_setting('admania-themeoption-expand9',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_adblocker_expand_custom_control($wp_customize,'admania-themeoption-expand9',array(
        'section' => 'admania-general-settings', 		
		'setting' => 'admania-themeoption-expand9',		
	)));
					
	// Add theme front-end adblocker mode Section, Setting, Control.
		
	$wp_customize->add_setting('admania_adblockaact',array(
	
	   'capability' => 'edit_theme_options',
	   'transport' => 'refresh',
	   'default' => 0,
	   'sanitize_callback' => 'absint',
	
	));
	
	$wp_customize->add_control('admania_adblocker_control',array(
	  
	  'type' => 'checkbox',
	  'section' => 'admania-general-settings',
	  'label' => esc_html__('Show adblocker mode','ad-mania'),
	  'settings' => 'admania_adblockaact',
	  
	));
	
	$wp_customize->add_setting('admania_adblocktitle',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));

	$wp_customize->add_control('admania_adblocker_text_control',array(
        'type' => 'text',
		'section' => 'admania-general-settings', 
		'label' => esc_html__('Change your Oh Snap text','ad-mania'),
		'settings' => 'admania_adblocktitle',
	));	
		
	$wp_customize->add_setting('admania_adblockdesp',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_textarea',
	));

	$wp_customize->add_control('admania_adblocker_desp_control',array(
        'type' => 'textarea',
		'section' => 'admania-general-settings', 
		'label' => esc_html__('Change your ad bock description text','ad-mania'),
		'settings' => 'admania_adblockdesp',
	));
	
	$wp_customize->add_setting('admania-themeoption-expand5',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_responsive_expand_custom_control($wp_customize,'admania-themeoption-expand5',array(
        'section' => 'admania-general-settings', 		
		'setting' => 'admania-themeoption-expand5',		
	)));
					
	// Add theme front-end responsive mode Section, Setting, Control.
		
	$wp_customize->add_setting('admania_responsive',array(
	
	   'capability' => 'edit_theme_options',
	   'transport' => 'refresh',
	   'default' => 0,
	   'sanitize_callback' => 'absint',
	
	));
	
	$wp_customize->add_control('admania_responsive_control',array(
	  
	  'type' => 'checkbox',
	  'section' => 'admania-general-settings',
	  'label' => esc_html__('Hide site responsive mode','ad-mania'),
	  'settings' => 'admania_responsive',
	  
	));

	// Add Blog settings section,setting,control
	
	$wp_customize->add_section('admania-blog-layout-section',array(
		'title' => esc_html__('Blog Layout Type','ad-mania'),
		'priority' => 12,
		'panel' => 'admania-panel-id'
	));	
			
	$wp_customize->add_setting('admania-themeoption-expand14',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_blog_layout_expand_custom_control($wp_customize,'admania-themeoption-expand14',array(
        'section' => 'admania-blog-layout-section', 		
		'setting' => 'admania-themeoption-expand14',		
	)));
	
	$wp_customize->add_setting('admania_blog_layout_type',array(
        'capability' => 'edit_theme_options',
		'default'    => 'amblyt1',
		'transport' => 'refresh',
        'sanitize_callback' => 'sanitize_text_field',
	));
	
	$wp_customize->add_control( new admania_input_layout_custom_control( $wp_customize,'admania_blog_layout_control',array(
        
		'section' => 'admania-blog-layout-section', 
		'label' => esc_html__('Choose the blog layout','ad-mania'),
		'settings' => 'admania_blog_layout_type',
		'description' => esc_html__('Here, you can choose blog layout','ad-mania'),
	    
	)));
	
	// Add Header layout settings section,setting,control
	
	$wp_customize->add_section('admania-header-layout-section',array(
		'title' => esc_html__('Header Layout Type','ad-mania'),
		'priority' => 13,
		'panel' => 'admania-panel-id'
	));	
			
	$wp_customize->add_setting('admania-themeoption-expand15',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_header_layout_expand_custom_control($wp_customize,'admania-themeoption-expand15',array(
        'section' => 'admania-header-layout-section', 		
		'setting' => 'admania-themeoption-expand15',		
	)));
		
	$wp_customize->add_setting('admania_headertype_scheme',array(
        'capability' => 'edit_theme_options',
		'default'    => 'amheader1',
		'transport' => 'refresh',
        'sanitize_callback' => 'sanitize_text_field',
	));
	
	$wp_customize->add_control( new admania_header_input_layout_expand_custom_control( $wp_customize,'admania_header_layout_control',array(
        
		'section' => 'admania-header-layout-section', 
		'label' => esc_html__('Choose the header layout','ad-mania'),
		'settings' => 'admania_headertype_scheme',
		'description' => esc_html__('Here, you can choose header layout','ad-mania'),
	    
	)));
	
	$wp_customize->selective_refresh->add_partial('admania_headertype_scheme', array(
       'selector' => '.admania-siteheader', 
    ));
	
	$wp_customize->add_setting('admania-themeoption-expand16',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_header_sticky_expand_custom_control($wp_customize,'admania-themeoption-expand16',array(
        'section' => 'admania-header-layout-section', 		
		'setting' => 'admania-themeoption-expand16',		
	)));
					
	// Add theme front-end header sticky mode Section, Setting, Control.
		
	$wp_customize->add_setting('admania_header_sticky_ondesktop_setting',array(
	
	   'capability' => 'edit_theme_options',
	   'transport' => 'refresh',
	   'default' => 0,
	   'sanitize_callback' => 'absint',
	
	));
	
	$wp_customize->add_control('admania_header_sticky_ondesktop_control',array(
	  
	  'type' => 'checkbox',
	  'section' => 'admania-header-layout-section',
	  'label' => esc_html__('Show Header Sticky On Desktop','ad-mania'),
	  'settings' => 'admania_header_sticky_ondesktop_setting',
	  
	));
	
	$wp_customize->add_setting('admania_header_sticky_onmobile_setting',array(
	
	   'capability' => 'edit_theme_options',
	   'transport' => 'refresh',
	   'default' => 0,
	   'sanitize_callback' => 'absint',
	
	));
	
	$wp_customize->add_control('admania_header_sticky_onmobile_control',array(
	  
	  'type' => 'checkbox',
	  'section' => 'admania-header-layout-section',
	  'label' => esc_html__('Show Header Sticky On Mobile','ad-mania'),
	  'settings' => 'admania_header_sticky_onmobile_setting',
	  
	));
	
	
	$wp_customize->add_setting('admania_hdrstkycustomlogo',array(
	  
	  'capability' => 'edit_theme_options',	  
	  'transport' => 'refresh',
	  'sanitize_callback' => 'esc_url'
	
	));
	
	$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize,'admania_hdrstkycustomlogo',array(
		'section' => 'admania-header-layout-section',
		'label' => esc_html__('Sticky Header Logo','ad-mania'),
		'settings' => 'admania_hdrstkycustomlogo',
		'description' => esc_html__('Required size for logo is 170X50','ad-mania'),
	)));
	
	
	$wp_customize->selective_refresh->add_partial('admania_hdrstkycustomlogo', array(
       'selector' => '.admania-header-sticky-mid', 
    )); 
	
	$wp_customize->add_setting('admania-themeoption-expand61',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_header_tp_latest_expand_custom_control($wp_customize,'admania-themeoption-expand61',array(
        'section' => 'admania-header-layout-section', 		
		'setting' => 'admania-themeoption-expand61',		
	)));
	
	$wp_customize->add_setting('admania_header_tp_latest_check_setting',array(
	
	   'capability' => 'edit_theme_options',
	   'transport' => 'refresh',
	   'default' => 0,
	   'sanitize_callback' => 'absint',
	
	));
	
	$wp_customize->add_control('admania_header_tp_latest_check_control',array(
	  
	  'type' => 'checkbox',
	  'section' => 'admania-header-layout-section',
	  'label' => esc_html__('Show Latest Techonlogy','ad-mania'),
	  'settings' => 'admania_header_tp_latest_check_setting',
	  
	));
	
	$wp_customize->selective_refresh->add_partial('admania_header_tp_latest_check_setting', array(
       'selector' => '.admania-header-ten', // facebook div class selector name
    ));
	
	$wp_customize->add_setting('admania_header_tp_latest_text_setting',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));

	$wp_customize->add_control('admania_header_tp_latest_text_control',array(
        'type' => 'text',
		'section' => 'admania-header-layout-section', 
		'label' => esc_html__('Latest Techonlogy Title','ad-mania'),
		'settings' => 'admania_header_tp_latest_text_setting',
	));	
	
	$wp_customize->selective_refresh->add_partial('admania_header_tp_latest_text_setting', array(
       'selector' => '.admania-header-eleven-top-left', // facebook div class selector name
       'render_callback' => 'admania_header_tp_latest_text'
	));
	
		$wp_customize->add_setting('admania_header_top_latest_setting',array(
        'capability' => 'edit_theme_options',		
		'default' => esc_html__('select','ad-mania'),
		'transport' => 'refresh',		
        'sanitize_callback' => 'sanitize_key'        
	));

	$wp_customize->add_control('admania_header_top_latest_control',array(
        'type' => 'select',		
		'section' => 'admania-header-layout-section', 
		'label' => esc_html__('Select Latest post order','ad-mania'),
		'settings' => 'admania_header_top_latest_setting',
		'description' => esc_html__('Choose the random (or) latest to display post','ad-mania'),
	    'choices' => array(
		   'latest' => esc_html__('Latest','ad-mania'),
		   'random' => esc_html__('Random','ad-mania'),
		 )
	));
	
	$wp_customize->add_setting('admania_lsttech_catids_setting',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_textarea',
	));

	$wp_customize->add_control('admania_lsttech_catids_control',array(
        'type' => 'textarea',
		'section' => 'admania-header-layout-section', 
		'label' => esc_html__('Enter the post id to display the post in the featured section','ad-mania'),
		'settings' => 'admania_lsttech_catids_setting',
	));
	
	$wp_customize->add_setting('admania-themeoption-expand18',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_header10_tp_offer_bar_expand_custom_control($wp_customize,'admania-themeoption-expand18',array(
        'section' => 'admania-header-layout-section', 		
		'setting' => 'admania-themeoption-expand18',		
	)));
	
	$wp_customize->add_setting('admania_header10_tp_offer_bar_check_setting',array(
	
	   'capability' => 'edit_theme_options',
	   'transport' => 'refresh',
	   'default' => 0,
	   'sanitize_callback' => 'absint',
	
	));
	
	$wp_customize->add_control('admania_header10_tp_offer_bar_check_control',array(
	  
	  'type' => 'checkbox',
	  'section' => 'admania-header-layout-section',
	  'label' => esc_html__('Show offer bar','ad-mania'),
	  'settings' => 'admania_header10_tp_offer_bar_check_setting',
	  
	));
	
	$wp_customize->selective_refresh->add_partial('admania_header10_tp_offer_bar_check_setting', array(
       'selector' => '.admania-headerinner-eleven-top', // facebook div class selector name
    ));
	
	
	$wp_customize->add_setting('admania_header10_tp_offer_bar_text_setting',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'postMessage',
        'sanitize_callback' => 'esc_html',
	));

	$wp_customize->add_control('admania_header10_tp_offer_bar_text_control',array(
        'type' => 'text',
		'section' => 'admania-header-layout-section', 
		'label' => esc_html__('offer bar title','ad-mania'),
		'settings' => 'admania_header10_tp_offer_bar_text_setting',
	));	
	
	
	$wp_customize->selective_refresh->add_partial('admania_header10_tp_offer_bar_text_setting', array(
       'selector' => '.admania-header-eleven-top-left h6',  
       'render_callback' => 'admania_header10_tp_offer_bar_text'  
   ));
	
	
	$wp_customize->add_setting('admania_header10_tp_offer_bar_viewmore_text_setting',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'postMessage',
        'sanitize_callback' => 'esc_html',
	));

	$wp_customize->add_control('admania_header10_tp_offer_bar_viewmore_text_control',array(
        'type' => 'text',
		'section' => 'admania-header-layout-section', 
		'label' => esc_html__('offer bar view more text','ad-mania'),
		'settings' => 'admania_header10_tp_offer_bar_viewmore_text_setting',
	));	
	
	$wp_customize->selective_refresh->add_partial('admania_header10_tp_offer_bar_viewmore_text_setting', array(
       'selector' => '.admania-headerinner-eleven-top a',  
       'render_callback' => 'admania_header10_tp_offer_bar_viewmore_text'  
    ));
	
	
	$wp_customize->add_setting('admania_header10_tp_offer_bar_viewmore_link_setting',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_url',
	));

	$wp_customize->add_control('admania_header10_tp_offer_bar_viewmore_link_control',array(
        'type' => 'text',
		'section' => 'admania-header-layout-section', 
		'label' => esc_html__('offer bar view more link','ad-mania'),
		'settings' => 'admania_header10_tp_offer_bar_viewmore_link_setting',
	));
	
	
	
	// Add Post layout settings section,setting,control
	
	$wp_customize->add_section('admania-post-layout-section',array(
		'title' => esc_html__('Post Layout Type','ad-mania'),
		'priority' => 14,
		'panel' => 'admania-panel-id'
	));	
			
	$wp_customize->add_setting('admania-themeoption-expand17',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_post_layout_expand_custom_control($wp_customize,'admania-themeoption-expand17',array(
        'section' => 'admania-post-layout-section', 		
		'setting' => 'admania-themeoption-expand17',		
	)));
		
	$wp_customize->add_setting('admania_splyts_scheme',array(
        'capability' => 'edit_theme_options',
		'default'    => 'amsplyt1',
		'transport' => 'refresh',
        'sanitize_callback' => 'sanitize_text_field',
	));
	
	$wp_customize->add_control( new admania_post_input_layout_expand_custom_control( $wp_customize,'admania_post_layout_control',array(
        'section' => 'admania-post-layout-section', 
		'label' => esc_html__('Choose the post layout','ad-mania'),
		'settings' => 'admania_splyts_scheme',
		'description' => esc_html__('Here, you can choose post layout','ad-mania'),
	)));
	
	$wp_customize->selective_refresh->add_partial('admania_splyts_scheme', array(
       'selector' => '.single .admania-sitemaincontent', 
    ));
	
	// Add Slider layout settings section,setting,control
	
	$wp_customize->add_section('admania-slider-section',array(
		'title' => esc_html__('Slider settings','ad-mania'),
		'priority' => 16,
		'theme_supports' => '',
		'panel' => 'admania-panel-id'
	));	
			
	$wp_customize->add_setting('admania-themeoption-expand19',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_slider1_layout_expand_custom_control($wp_customize,'admania-themeoption-expand19',array(
        'section' => 'admania-slider-section', 		
		'setting' => 'admania-themeoption-expand19',		
	)));
	
	// Add theme front-end slider mode Section, Setting, Control.
		
	$wp_customize->add_setting('hm_slideractive',array(
	
	   'capability' => 'edit_theme_options',
	   'transport' => 'refresh',
	   'default' => 0,
	   'sanitize_callback' => 'absint',
	
	));
	
	$wp_customize->add_control('admania_slider1_control',array(
	  
	  'type' => 'checkbox',
	  'section' => 'admania-slider-section',
	  'label' => esc_html__('Show slider mode','ad-mania'),
	  'settings' => 'hm_slideractive',
	  
	));
	
	$wp_customize->selective_refresh->add_partial('hm_slideractive', array(
       'selector' => '.admania-layout1contentareainner .admania-featuredslider', // facebook div class selector name
    ));
		
	
	$wp_customize->add_setting('admania-themeoption-note',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_slider_note_expand_custom_control($wp_customize,'admania-themeoption-note',array(
        'section' => 'admania-slider-section', 		
		'setting' => 'admania-themeoption-note',		
	)));
	
	$wp_customize->add_setting('admania_slider1_category_setting',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh', 
        'default' => 1,		
        'sanitize_callback' => 'absint'		
	));
	
	$wp_customize->add_control('admania_slider1_category_control',array(
        'type' => 'select',		
		'section' => 'admania-slider-section', 
		'label' => esc_html__('Choose category name','ad-mania'),
		'settings' => 'admania_slider1_category_setting',
		'description' => esc_html__('Here, you can select the category name to display those posts in slider','ad-mania'),
	    'choices'  => $admania_cats
	));	
	
	$wp_customize->add_setting('hm_sliderpstids',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_textarea',
	));

	$wp_customize->add_control('admania_slider1_postids_control',array(
        'type' => 'textarea',
		'section' => 'admania-slider-section', 
		'label' => esc_html__('Enter the post id to display the post in the slider section','ad-mania'),
		'settings' => 'hm_sliderpstids',
	));
	
	$wp_customize->add_setting('hm_sliderctgrsid',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_textarea',
	));

	$wp_customize->add_control('admania_slider1_catids_control',array(
        'type' => 'textarea',
		'section' => 'admania-slider-section', 
		'label' => esc_html__('Enter the category id to display the post in the slider section','ad-mania'),
		'settings' => 'hm_sliderctgrsid',
	));
	
	$wp_customize->add_setting('hm_sliderrandorlatst',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'sanitize_key',
	));

	$wp_customize->add_control('admania_slider1_post_order_control',array(
        'type' => 'radio',
		'section' => 'admania-slider-section', 
		'label' => esc_html__('Post Order','ad-mania'),
		'settings' => 'hm_sliderrandorlatst',
		'choices' => array(
		 'latest' => esc_html__('Latest','ad-mania'),
		 'random' => esc_html__('Random','ad-mania')
		),
	));	
	
	$wp_customize->add_setting('hm_sliderpostperpage',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh', 
        'sanitize_callback' => 'absint', // The hue is stored as a positive integer.		
	));

	$wp_customize->add_control('admania_slider1_post_count_control',array(
        'type' => 'text',		
		'section' => 'admania-slider-section', 
		'label' => esc_html__('post count','ad-mania'),
		'settings' => 'hm_sliderpostperpage',		
	));

    $wp_customize->add_setting('admania-themeoption-expand20',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_slider2_layout_expand_custom_control($wp_customize,'admania-themeoption-expand20',array(
        'section' => 'admania-slider-section', 		
		'setting' => 'admania-themeoption-expand20',		
	)));
	
	// Add theme front-end slider mode Section, Setting, Control.
		
	$wp_customize->add_setting('hm_slideractive1',array(
	
	   'capability' => 'edit_theme_options',
	   'transport' => 'refresh',
	   'default' => 0,
	   'sanitize_callback' => 'absint',
	
	));
	
	$wp_customize->add_control('admania_slider2_control',array(
	  
	  'type' => 'checkbox',
	  'section' => 'admania-slider-section',
	  'label' => esc_html__('Show slider mode','ad-mania'),
	  'settings' => 'hm_slideractive1',
	  
	));
	
	$wp_customize->selective_refresh->add_partial('hm_slideractive1', array(
       'selector' => '.admania-ly2ftsection', // facebook div class selector name
    ));
	
	
	$wp_customize->add_setting('admania-themeoption-note2',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_slider_note_expand_custom_control($wp_customize,'admania-themeoption-note2',array(
        'section' => 'admania-slider-section', 		
		'setting' => 'admania-themeoption-note2',		
	)));
	
	$wp_customize->add_setting('hm_sliderctgs1',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh', 
        'default' => 1,		
        'sanitize_callback' => 'absint'		
	));
	
	$wp_customize->add_control('admania_slider2_category_control',array(
        'type' => 'select',		
		'section' => 'admania-slider-section', 
		'label' => esc_html__('Choose category name','ad-mania'),
		'settings' => 'hm_sliderctgs1',
		'description' => esc_html__('Here, you can select the category name to display those posts in slider','ad-mania'),
	    'choices'  => $admania_cats
	));	
	
	$wp_customize->add_setting('hm_sliderpstids1',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_textarea',
	));

	$wp_customize->add_control('admania_slider2_postids_control',array(
        'type' => 'textarea',
		'section' => 'admania-slider-section', 
		'label' => esc_html__('Enter the post id to display the post in the slider section','ad-mania'),
		'settings' => 'hm_sliderpstids1',
	));
	
	$wp_customize->add_setting('hm_sliderctgrsid1',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_textarea',
	));

	$wp_customize->add_control('admania_slider2_catids_control',array(
        'type' => 'textarea',
		'section' => 'admania-slider-section', 
		'label' => esc_html__('Enter the category id to display the post in the slider section','ad-mania'),
		'settings' => 'hm_sliderctgrsid1',
	));	 	
	
	$wp_customize->add_setting('hm_sliderrandorlatst1',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'sanitize_key',
	));

	$wp_customize->add_control('admania_slider2_post_order_control',array(
        'type' => 'radio',
		'section' => 'admania-slider-section', 
		'label' => esc_html__('Post Order','ad-mania'),
		'settings' => 'hm_sliderrandorlatst1',
		'choices' => array(
		 'latest' => esc_html__('Latest','ad-mania'),
		 'random' => esc_html__('Random','ad-mania')
		),
	));	
	
	$wp_customize->add_setting('hm_sliderpostperpage1',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh', 
        'sanitize_callback' => 'absint', // The hue is stored as a positive integer.		
	));

	$wp_customize->add_control('admania_slider2_post_count_control',array(
        'type' => 'text',		
		'section' => 'admania-slider-section', 
		'label' => esc_html__('post count','ad-mania'),
		'settings' => 'hm_sliderpostperpage1',		
	));
	
	$wp_customize->add_setting('admania-themeoption-expand21',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_slider3_layout_expand_custom_control($wp_customize,'admania-themeoption-expand21',array(
        'section' => 'admania-slider-section', 		
		'setting' => 'admania-themeoption-expand21',		
	)));
	
	// Add theme front-end slider mode Section, Setting, Control.
		
	$wp_customize->add_setting('hm_slideractive2',array(
	
	   'capability' => 'edit_theme_options',
	   'transport' => 'refresh',
	   'default' => 0,
	   'sanitize_callback' => 'absint',
	
	));
	
	$wp_customize->add_control('admania_slider3_control',array(
	  
	  'type' => 'checkbox',
	  'section' => 'admania-slider-section',
	  'label' => esc_html__('Show slider mode','ad-mania'),
	  'settings' => 'hm_slideractive2',
	  
	));
	
	$wp_customize->selective_refresh->add_partial('hm_slideractive2', array(
       'selector' => '.admania_ly3ftsection', 
    ));
	
	$wp_customize->add_setting('admania-themeoption-note3',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_slider_note_expand_custom_control($wp_customize,'admania-themeoption-note3',array(
        'section' => 'admania-slider-section', 		
		'setting' => 'admania-themeoption-note3',		
	)));
	
	$wp_customize->add_setting('hm_sliderctgs2',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh', 
        'default' => 1,		
        'sanitize_callback' => 'absint'		
	));
	
	$wp_customize->add_control('admania_slider3_category_control',array(
        'type' => 'select',		
		'section' => 'admania-slider-section', 
		'label' => esc_html__('Choose category name','ad-mania'),
		'settings' => 'hm_sliderctgs2',
		'description' => esc_html__('Here, you can select the category name to display those posts in slider','ad-mania'),
	    'choices'  => $admania_cats
	));
	
	$wp_customize->add_setting('hm_sliderpstids2',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_textarea',
	));

	$wp_customize->add_control('admania_slider3_postids_control',array(
        'type' => 'textarea',
		'section' => 'admania-slider-section', 
		'label' => esc_html__('Enter the post id to display the post in the slider section','ad-mania'),
		'settings' => 'hm_sliderpstids2',
	));
	
	$wp_customize->add_setting('hm_sliderctgrsid2',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_textarea',
	));

	$wp_customize->add_control('admania_slider3_catids_control',array(
        'type' => 'textarea',
		'section' => 'admania-slider-section', 
		'label' => esc_html__('Enter the category id to display the post in the slider section','ad-mania'),
		'settings' => 'hm_sliderctgrsid2',
	));	 	
	
	$wp_customize->add_setting('hm_sliderpostperpage2',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'sanitize_key',
	));

	$wp_customize->add_control('admania_slider3_post_order_control',array(
        'type' => 'radio',
		'section' => 'admania-slider-section', 
		'label' => esc_html__('Post Order','ad-mania'),
		'settings' => 'hm_sliderpostperpage2',
		'choices' => array(
		 'latest' => esc_html__('Latest','ad-mania'),
		 'random' => esc_html__('Random','ad-mania')
		),
	));	
	
	$wp_customize->add_setting('hm_sliderrandorlatst2',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh', 
        'sanitize_callback' => 'absint', // The hue is stored as a positive integer.		
	));

	$wp_customize->add_control('admania_slider3_post_count_control',array(
        'type' => 'text',		
		'section' => 'admania-slider-section', 
		'label' => esc_html__('post count','ad-mania'),
		'settings' => 'hm_sliderrandorlatst2',
		
	));
	
	$wp_customize->add_setting('admania-themeoption-expand60',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_slider4_layout_expand_custom_control($wp_customize,'admania-themeoption-expand60',array(
        'section' => 'admania-slider-section', 		
		'setting' => 'admania-themeoption-expand60',		
	)));
	
	// Add theme front-end slider mode Section, Setting, Control.
		
	$wp_customize->add_setting('hm_slideractive4',array(
	
	   'capability' => 'edit_theme_options',
	   'transport' => 'refresh',
	   'default' => 0,
	   'sanitize_callback' => 'absint',
	
	));
	
	$wp_customize->add_control('admania_slider4_control',array(
	  
	  'type' => 'checkbox',
	  'section' => 'admania-slider-section',
	  'label' => esc_html__('Show slider mode','ad-mania'),
	  'settings' => 'hm_slideractive4',
	  
	));
		
	$wp_customize->selective_refresh->add_partial('hm_slideractive4', array(
       'selector' => '.admania_ly4ftsection', 
    ));
		
	$wp_customize->add_setting('admania-themeoption-note1',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_slider_note_expand_custom_control($wp_customize,'admania-themeoption-note1',array(
        'section' => 'admania-slider-section', 		
		'setting' => 'admania-themeoption-note1',		
	)));
	
	$wp_customize->add_setting('hm_sliderctgs4',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh', 
        'default' => 1,		
        'sanitize_callback' => 'absint'		
	));
	
	$wp_customize->add_control('admania_slider4_category_control',array(
        'type' => 'select',		
		'section' => 'admania-slider-section', 
		'label' => esc_html__('Choose category name','ad-mania'),
		'settings' => 'hm_sliderctgs4',
		'description' => esc_html__('Here, you can select the category name to display those posts in slider','ad-mania'),
	    'choices'  => $admania_cats
	));
	
	
	$wp_customize->add_setting('hm_sliderpstids4',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_textarea',
	));

	$wp_customize->add_control('admania_slider4_postids_control',array(
        'type' => 'textarea',
		'section' => 'admania-slider-section', 
		'label' => esc_html__('Enter the post id to display the post in the slider section','ad-mania'),
		'settings' => 'hm_sliderpstids4',
	));
	
	$wp_customize->add_setting('hm_sliderctgrsid4',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_textarea',
	));

	$wp_customize->add_control('admania_slider4_catids_control',array(
        'type' => 'textarea',
		'section' => 'admania-slider-section', 
		'label' => esc_html__('Enter the category id to display the post in the slider section','ad-mania'),
		'settings' => 'hm_sliderctgrsid4',
	));	 	
	
	$wp_customize->add_setting('hm_sliderrandorlatst4',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'sanitize_key',
	));

	$wp_customize->add_control('admania_slider4_post_order_control',array(
        'type' => 'radio',
		'section' => 'admania-slider-section', 
		'label' => esc_html__('Post Order','ad-mania'),
		'settings' => 'hm_sliderrandorlatst4',
		'choices' => array(
		 'latest' => esc_html__('Latest','ad-mania'),
		 'random' => esc_html__('Random','ad-mania')
		),
	));	
	
	$wp_customize->add_setting('hm_sliderpostperpage4',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh', 
        'sanitize_callback' => 'absint', // The hue is stored as a positive integer.		
	));

	$wp_customize->add_control('admania_slider4_post_count_control',array(
        'type' => 'text',		
		'section' => 'admania-slider-section', 
		'label' => esc_html__('post count','ad-mania'),
		'settings' => 'hm_sliderpostperpage4',
		
	));
	
	$wp_customize->add_setting('admania-themeoption-expand22',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_slider5_layout_expand_custom_control($wp_customize,'admania-themeoption-expand22',array(
        'section' => 'admania-slider-section', 		
		'setting' => 'admania-themeoption-expand22',		
	)));
	
	// Add theme front-end slider mode Section, Setting, Control.
		
	$wp_customize->add_setting('hm_slideractive5',array(
	
	   'capability' => 'edit_theme_options',
	   'transport' => 'refresh',
	   'default' => 0,
	   'sanitize_callback' => 'absint',
	
	));
	
	$wp_customize->add_control('admania_slider5_control',array(
	  
	  'type' => 'checkbox',
	  'section' => 'admania-slider-section',
	  'label' => esc_html__('Show slider mode','ad-mania'),
	  'settings' => 'hm_slideractive5',
	  
	));
	
	$wp_customize->selective_refresh->add_partial('hm_slideractive5', array(
       'selector' => '.admania-bly5featuredslider .admania-siteinner', 
    ));
	
	
	$wp_customize->add_setting('admania-themeoption-note1',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_slider_note_expand_custom_control($wp_customize,'admania-themeoption-note1',array(
        'section' => 'admania-slider-section', 		
		'setting' => 'admania-themeoption-note1',		
	)));
	
	$wp_customize->add_setting('hm_sliderctgs5',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh', 
        'default' => 1,		
        'sanitize_callback' => 'absint'		
	));
	
	$wp_customize->add_control('admania_slider5_category_control',array(
        'type' => 'select',		
		'section' => 'admania-slider-section', 
		'label' => esc_html__('Choose category name','ad-mania'),
		'settings' => 'hm_sliderctgs5',
		'description' => esc_html__('Here, you can select the category name to display those posts in slider','ad-mania'),
	    'choices'  => $admania_cats
	));
	
	$wp_customize->add_setting('hm_sliderpstids5',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_textarea',
	));

	$wp_customize->add_control('admania_slider5_postids_control',array(
        'type' => 'textarea',
		'section' => 'admania-slider-section', 
		'label' => esc_html__('Enter the post id to display the post in the slider section','ad-mania'),
		'settings' => 'hm_sliderpstids5',
	));
	
	$wp_customize->add_setting('hm_sliderctgrsid5',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_textarea',
	));

	$wp_customize->add_control('admania_slider5_catids_control',array(
        'type' => 'textarea',
		'section' => 'admania-slider-section', 
		'label' => esc_html__('Enter the category id to display the post in the slider section','ad-mania'),
		'settings' => 'hm_sliderctgrsid5',
	));	 	
	
	$wp_customize->add_setting('hm_sliderrandorlatst5',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'sanitize_key',
	));

	$wp_customize->add_control('admania_slider5_post_order_control',array(
        'type' => 'radio',
		'section' => 'admania-slider-section', 
		'label' => esc_html__('Post Order','ad-mania'),
		'settings' => 'hm_sliderrandorlatst5',
		'choices' => array(
		 'latest' => esc_html__('Latest','ad-mania'),
		 'random' => esc_html__('Random','ad-mania')
		),
	));	
	
	$wp_customize->add_setting('hm_sliderpostperpage5',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh', 
        'sanitize_callback' => 'absint', // The hue is stored as a positive integer.		
	));

	$wp_customize->add_control('admania_slider5_post_count_control',array(
        'type' => 'text',		
		'section' => 'admania-slider-section', 
		'label' => esc_html__('post count','ad-mania'),
		'settings' => 'hm_sliderpostperpage5',
		
	));
	
	$wp_customize->add_setting('admania-themeoption-expand23',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_slider6_layout_expand_custom_control($wp_customize,'admania-themeoption-expand23',array(
        'section' => 'admania-slider-section', 		
		'setting' => 'admania-themeoption-expand23',		
	)));
	
	// Add theme front-end slider mode Section, Setting, Control.
		
	$wp_customize->add_setting('hm_slideractive7',array(
	
	   'capability' => 'edit_theme_options',
	   'transport' => 'refresh',
	   'default' => 0,
	   'sanitize_callback' => 'absint',
	
	));
	
	$wp_customize->add_control('admania_slider6_control',array(
	  
	  'type' => 'checkbox',
	  'section' => 'admania-slider-section',
	  'label' => esc_html__('Show slider mode','ad-mania'),
	  'settings' => 'hm_slideractive7',
	  
	));
		
	$wp_customize->selective_refresh->add_partial('hm_slideractive7', array(
       'selector' => '.admania-boxedlayfeatured', 
    ));
		
	$wp_customize->add_setting('admania-themeoption-note1',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_slider_note_expand_custom_control($wp_customize,'admania-themeoption-note1',array(
        'section' => 'admania-slider-section', 		
		'setting' => 'admania-themeoption-note1',		
	)));
	
	$wp_customize->add_setting('hm_sliderctgs7',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh', 
        'default' => 1,		
        'sanitize_callback' => 'absint'		
	));
	
	$wp_customize->add_control('admania_slider6_category_control',array(
        'type' => 'select',		
		'section' => 'admania-slider-section', 
		'label' => esc_html__('Choose category name','ad-mania'),
		'settings' => 'hm_sliderctgs7',
		'description' => esc_html__('Here, you can select the category name to display those posts in slider','ad-mania'),
	    'choices'  => $admania_cats
	));
	
	
	$wp_customize->add_setting('hm_sliderpstids7',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_textarea',
	));

	$wp_customize->add_control('admania_slider6_postids_control',array(
        'type' => 'textarea',
		'section' => 'admania-slider-section', 
		'label' => esc_html__('Enter the post id to display the post in the slider section','ad-mania'),
		'settings' => 'hm_sliderpstids7',
	));
	
	$wp_customize->add_setting('hm_sliderctgrsid7',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_textarea',
	));

	$wp_customize->add_control('admania_slider6_catids_control',array(
        'type' => 'textarea',
		'section' => 'admania-slider-section', 
		'label' => esc_html__('Enter the category id to display the post in the slider section','ad-mania'),
		'settings' => 'hm_sliderctgrsid7',
	));	 	
	
	$wp_customize->add_setting('hm_sliderrandorlatst7',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'sanitize_key',
	));

	$wp_customize->add_control('admania_slider6_post_order_control',array(
        'type' => 'radio',
		'section' => 'admania-slider-section', 
		'label' => esc_html__('Post Order','ad-mania'),
		'settings' => 'hm_sliderrandorlatst7',
		'choices' => array(
		 'latest' => esc_html__('Latest','ad-mania'),
		 'random' => esc_html__('Random','ad-mania')
		),
	));
	
	if ( class_exists( 'Woocommerce' ) ) {
	
	$wp_customize->add_setting('admania-themeoption-expand54',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_slider8_layout_expand_custom_control($wp_customize,'admania-themeoption-expand54',array(
        'section' => 'admania-slider-section', 		
		'setting' => 'admania-themeoption-expand54',		
	)));
	
	// Add theme front-end slider mode Section, Setting, Control.
		
	$wp_customize->add_setting('hm_slideractive6',array(
	
	   'capability' => 'edit_theme_options',
	   'transport' => 'refresh',
	   'default' => 0,
	   'sanitize_callback' => 'absint',
	
	));
	
	$wp_customize->add_control('admania_slider8_control',array(
	  
	  'type' => 'checkbox',
	  'section' => 'admania-slider-section',
	  'label' => esc_html__('Show slider mode','ad-mania'),
	  'settings' => 'hm_slideractive6',
	  
	));
	
	
	
	$wp_customize->add_setting('admania-themeoption-note1',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_slider_note_expand_custom_control($wp_customize,'admania-themeoption-note1',array(
        'section' => 'admania-slider-section', 		
		'setting' => 'admania-themeoption-note1',		
	)));
	
	$wp_customize->add_setting('hm_sliderctgs6',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh', 
        'default' => 1,		
        'sanitize_callback' => 'absint'		
	));
	
	$wp_customize->add_control('admania_slider8_category_control',array(
        'type' => 'select',		
		'section' => 'admania-slider-section', 
		'label' => esc_html__('Choose category name','ad-mania'),
		'settings' => 'hm_sliderctgs6',
		'description' => esc_html__('Here, you can select the category name to display those posts in slider','ad-mania'),
	    'choices'  =>  $admania_product_cattypes
	));
	
	
	$wp_customize->add_setting('hm_sliderpstids6',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_textarea',
	));

	$wp_customize->add_control('admania_slider8_postids_control',array(
        'type' => 'textarea',
		'section' => 'admania-slider-section', 
		'label' => esc_html__('Enter the post id to display the post in the slider section','ad-mania'),
		'settings' => 'hm_sliderpstids6',
	));
	
	$wp_customize->add_setting('hm_sliderctgrsid6',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_textarea',
	));

	$wp_customize->add_control('admania_slider8_catids_control',array(
        'type' => 'textarea',
		'section' => 'admania-slider-section', 
		'label' => esc_html__('Enter the category id to display the post in the slider section','ad-mania'),
		'settings' => 'hm_sliderctgrsid6',
	));	 	
	
		$wp_customize->add_setting('hm_sliderrandorlatst6',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'sanitize_key',
	));

	$wp_customize->add_control('admania_slider8_post_order_control',array(
        'type' => 'radio',
		'section' => 'admania-slider-section', 
		'label' => esc_html__('Post Order','ad-mania'),
		'settings' => 'hm_sliderrandorlatst6',
		'choices' => array(
		 'latest' => esc_html__('Latest','ad-mania'),
		 'random' => esc_html__('Random','ad-mania')
		),
	));	
	
	$wp_customize->add_setting('hm_sliderpostperpage6',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh', 
        'sanitize_callback' => 'absint', // The hue is stored as a positive integer.		
	));

	$wp_customize->add_control('admania_slider8_post_count_control',array(
        'type' => 'text',		
		'section' => 'admania-slider-section', 
		'label' => esc_html__('post count','ad-mania'),
		'settings' => 'hm_sliderpostperpage6',
		
	));	
	
    }
	
	$wp_customize->add_setting('admania-themeoption-expand55',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_slider7_layout_expand_custom_control($wp_customize,'admania-themeoption-expand55',array(
        'section' => 'admania-slider-section', 		
		'setting' => 'admania-themeoption-expand55',		
	)));
	
	// Add theme front-end slider mode Section, Setting, Control.
		
	$wp_customize->add_setting('mb_slideractive',array(
	
	   'capability' => 'edit_theme_options',
	   'transport' => 'refresh',
	   'default' => 0,
	   'sanitize_callback' => 'absint',
	
	));
	
	$wp_customize->add_control('admania_mb_slideractive_control',array(
	  
	  'type' => 'checkbox',
	  'section' => 'admania-slider-section',
	  'label' => esc_html__('Show slider mode','ad-mania'),
	  'settings' => 'mb_slideractive',
	  
	));
	
	$wp_customize->selective_refresh->add_partial('mb_slideractive', array(
       'selector' => '.admania-mbsitemain .admania-featuredslider', 
    ));
	
	
	$wp_customize->add_setting('admania-themeoption-note1',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_slider_note_expand_custom_control($wp_customize,'admania-themeoption-note1',array(
        'section' => 'admania-slider-section', 		
		'setting' => 'admania-themeoption-note1',		
	)));
	
	$wp_customize->add_setting('mb_sliderctgs',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh', 
        'default' => 1,		
        'sanitize_callback' => 'absint'		
	));
	
	$wp_customize->add_control('admania_mb_slideractive_category_control',array(
        'type' => 'select',		
		'section' => 'admania-slider-section', 
		'label' => esc_html__('Choose category name','ad-mania'),
		'settings' => 'mb_sliderctgs',
		'description' => esc_html__('Here, you can select the category name to display those posts in slider','ad-mania'),
	    'choices'  => $admania_cats
	));
	
	
	$wp_customize->add_setting('mb_sliderpstids',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_textarea',
	));

	$wp_customize->add_control('admania_mb_slideractive_postids_control',array(
        'type' => 'textarea',
		'section' => 'admania-slider-section', 
		'label' => esc_html__('Enter the post id to display the post in the slider section','ad-mania'),
		'settings' => 'mb_sliderpstids',
	));
	
	$wp_customize->add_setting('mb_sliderctgrsid',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_textarea',
	));

	$wp_customize->add_control('admania_mb_slideractive_catids_control',array(
        'type' => 'textarea',
		'section' => 'admania-slider-section', 
		'label' => esc_html__('Enter the category id to display the post in the slider section','ad-mania'),
		'settings' => 'mb_sliderctgrsid',
	));	 	
	
	$wp_customize->add_setting('mb_sliderrandorlatst',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'sanitize_key',
	));

	$wp_customize->add_control('admania_mb_slideractive_post_order_control',array(
        'type' => 'radio',
		'section' => 'admania-slider-section', 
		'label' => esc_html__('Post Order','ad-mania'),
		'settings' => 'mb_sliderrandorlatst',
		'choices' => array(
		 'latest' => esc_html__('Latest','ad-mania'),
		 'random' => esc_html__('Random','ad-mania')
		),
	));	
	
	$wp_customize->add_setting('mb_sliderpostperpage',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh', 
        'sanitize_callback' => 'absint', // The hue is stored as a positive integer.		
	));

	$wp_customize->add_control('admania_mb_slideractive_post_count_control',array(
        'type' => 'text',		
		'section' => 'admania-slider-section', 
		'label' => esc_html__('post count','ad-mania'),
		'settings' => 'mb_sliderpostperpage',
		
	));
	
	// Add Featured Slider layout settings section,setting,control
	
	$wp_customize->add_section('admania-featured-section',array(
		'title' => esc_html__('Featured settings','ad-mania'),
		'priority' => 16,
		'panel' => 'admania-panel-id'
	));	
			
	$wp_customize->add_setting('admania-themeoption-expand24',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_ftd_slider1_layout_expand_custom_control($wp_customize,'admania-themeoption-expand24',array(
        'section' => 'admania-featured-section', 		
		'setting' => 'admania-themeoption-expand24',		
	)));
	
	// Add theme front-end slider mode Section, Setting, Control.
		
	$wp_customize->add_setting('admania_featuredactv',array(
	
	   'capability' => 'edit_theme_options',
	   'transport' => 'refresh',
	   'default' => 0,
	   'sanitize_callback' => 'absint',
	
	));
	
	$wp_customize->add_control('admania_ftd_slider1_control',array(
	  
	  'type' => 'checkbox',
	  'section' => 'admania-featured-section',
	  'label' => esc_html__('Show slider mode','ad-mania'),
	  'settings' => 'admania_featuredactv',
	  
	));
	
	$wp_customize->selective_refresh->add_partial('admania_featuredactv', array(
       'selector' => '.admania-featuredcategory', 
    ));	
	
	$wp_customize->add_setting('admania-themeoption-note5',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_slider_note_expand_custom_control($wp_customize,'admania-themeoption-note5',array(
        'section' => 'admania-featured-section', 		
		'setting' => 'admania-themeoption-note5',		
	)));
	
	$wp_customize->add_setting('admania_ftdcatgrs',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh', 
        'default' => 1,		
        'sanitize_callback' => 'absint'		
	));
	
	$wp_customize->add_control('admania_ftd_slider1_category_control',array(
        'type' => 'select',		
		'section' => 'admania-featured-section', 
		'label' => esc_html__('Choose category name','ad-mania'),
		'settings' => 'admania_ftdcatgrs',
		'description' => esc_html__('Here, you can select the category name to display those posts in slider','ad-mania'),
	    'choices'  => $admania_cats
	));
	
	
	$wp_customize->add_setting('admania_ftdpstid',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_textarea',
	));

	$wp_customize->add_control('admania_ftd_slider1_postids_control',array(
        'type' => 'textarea',
		'section' => 'admania-featured-section', 
		'label' => esc_html__('Enter the post id to display the post in the slider section','ad-mania'),
		'settings' => 'admania_ftdpstid',
	));
	
	$wp_customize->add_setting('admania_ftdcatid',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_textarea',
	));

	$wp_customize->add_control('admania_ftd_slider1_catids_control',array(
        'type' => 'textarea',
		'section' => 'admania-featured-section', 
		'label' => esc_html__('Enter the category id to display the post in the slider section','ad-mania'),
		'settings' => 'admania_ftdcatid',
	));
	
	$wp_customize->add_setting('admania_randorlatst1',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'sanitize_key',
	));

	$wp_customize->add_control('admania_ftd_slider1_post_order_control',array(
        'type' => 'radio',
		'section' => 'admania-featured-section', 
		'label' => esc_html__('Post Order','ad-mania'),
		'settings' => 'admania_randorlatst1',
		'choices' => array(
		 'latest' => esc_html__('Latest','ad-mania'),
		 'random' => esc_html__('Random','ad-mania')
		),
	));	
	
	 $wp_customize->add_setting('admania-themeoption-expand25',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_ftd_slider2_layout_expand_custom_control($wp_customize,'admania-themeoption-expand25',array(
        'section' => 'admania-featured-section', 		
		'setting' => 'admania-themeoption-expand25',		
	)));
	
	// Add theme front-end slider mode Section, Setting, Control.
		
	$wp_customize->add_setting('admania_featuredactv1',array(
	
	   'capability' => 'edit_theme_options',
	   'transport' => 'refresh',
	   'default' => 0,
	   'sanitize_callback' => 'absint',
	
	));
	
	$wp_customize->add_control('admania_ftd_slider2_control',array(
	  
	  'type' => 'checkbox',
	  'section' => 'admania-featured-section',
	  'label' => esc_html__('Show featured mode','ad-mania'),
	  'settings' => 'admania_featuredactv1',
	  
	));
	
	$wp_customize->selective_refresh->add_partial('admania_featuredactv1', array(
       'selector' => '.admania-featuredcategory1', 
    ));
	
	$wp_customize->add_setting('admania-themeoption-note4',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_slider_note_expand_custom_control($wp_customize,'admania-themeoption-note4',array(
        'section' => 'admania-featured-section', 		
		'setting' => 'admania-themeoption-note4',		
	)));
	
	$wp_customize->add_setting('admania_ftdcatgrs1',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh', 
        'default' => 1,		
        'sanitize_callback' => 'absint'		
	));
	
	$wp_customize->add_control('admania_ftd_slider2_category_control',array(
        'type' => 'select',		
		'section' => 'admania-featured-section', 
		'label' => esc_html__('Choose category name','ad-mania'),
		'settings' => 'admania_ftdcatgrs1',
		'description' => esc_html__('Here, you can select the category name to display those posts in slider','ad-mania'),
	    'choices'  => $admania_cats
	));
	
	$wp_customize->add_setting('admania_ftdpstid1',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_textarea',
	));

	$wp_customize->add_control('admania_ftd_slider2_postids_control',array(
        'type' => 'textarea',
		'section' => 'admania-featured-section', 
		'label' => esc_html__('Enter the post id to display the post in the slider section','ad-mania'),
		'settings' => 'admania_ftdpstid1',
	));
	
	$wp_customize->add_setting('admania_ftdcatid1',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_textarea',
	));

	$wp_customize->add_control('admania_ftd_slider2_catids_control',array(
        'type' => 'textarea',
		'section' => 'admania-featured-section', 
		'label' => esc_html__('Enter the category id to display the post in the slider section','ad-mania'),
		'settings' => 'admania_ftdcatid1',
	));	 	
	
	$wp_customize->add_setting('admania_randorlatst2',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'sanitize_key',
	));

	$wp_customize->add_control('admania_ftd_slider2_post_order_control',array(
        'type' => 'radio',
		'section' => 'admania-featured-section', 
		'label' => esc_html__('Post Order','ad-mania'),
		'settings' => 'admania_randorlatst2',
		'choices' => array(
		 'latest' => esc_html__('Latest','ad-mania'),
		 'random' => esc_html__('Random','ad-mania')
		),
	));	
	
	// Add Sidebar section,setting,control
	
	$wp_customize->add_section('admania-sidebar-section',array(
		'title' => esc_html__('Sidebar Settings','ad-mania'),
		'priority' => 17,
		'panel' => 'admania-panel-id'
	));	
			
	$wp_customize->add_setting('admania-themeoption-expand26',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_sidebar_expand_custom_control($wp_customize,'admania-themeoption-expand26',array(
        'section' => 'admania-sidebar-section', 		
		'setting' => 'admania-themeoption-expand26',		
	)));
	
	// Add theme front-end slider mode Section, Setting, Control.
		
	$wp_customize->add_setting('admania_dabothsidebar',array(
	
	   'capability' => 'edit_theme_options',
	   'transport' => 'refresh',
	   'default' => 0,
	   'sanitize_callback' => 'absint',
	
	));
	
	$wp_customize->add_control('admania_dabothsidebar_control',array(
	  
	  'type' => 'checkbox',
	  'section' => 'admania-sidebar-section',
	  'label' => esc_html__('Disable the Content Left & Right Sidebar','ad-mania'),
	  'settings' => 'admania_dabothsidebar',
	  
	));
	
	$wp_customize->add_setting('layt4_cnt_lstsdbr',array(
	
	   'capability' => 'edit_theme_options',
	   'transport' => 'refresh',
	   'default' => 0,
	   'sanitize_callback' => 'absint',
	
	));
	
	$wp_customize->add_control('admania_layt4_cnt_lstsdbr_control',array(
	  
	  'type' => 'checkbox',
	  'section' => 'admania-sidebar-section',
	  'label' => esc_html__(' Disable Secondary Sidebar','ad-mania'),
	  'settings' => 'layt4_cnt_lstsdbr',
	  
	));
	
	$wp_customize->add_setting('layt4_cnt_rgtsdbr',array(
	
	   'capability' => 'edit_theme_options',
	   'transport' => 'refresh',
	   'default' => 0,
	   'sanitize_callback' => 'absint',
	
	));
	
	$wp_customize->add_control('admania_layt4_cnt_rgtsdbr_control',array(
	  
	  'type' => 'checkbox',
	  'section' => 'admania-sidebar-section',
	  'label' => esc_html__('Disable Primary Sidebar :','ad-mania'),
	  'settings' => 'layt4_cnt_rgtsdbr',
	  
	));
	
	$wp_customize->add_setting('layt4_cnt_frstlaytlstsdbr',array(
	
	   'capability' => 'edit_theme_options',
	   'transport' => 'refresh',
	   'default' => 0,
	   'sanitize_callback' => 'absint',
	
	));
	
	$wp_customize->add_control('admania_layt4_cnt_frstlaytlstsdbr_control',array(
	  
	  'type' => 'checkbox',
	  'section' => 'admania-sidebar-section',
	  'label' => esc_html__(' Disable Layout4 Secondary2 Sidebar','ad-mania'),
	  'settings' => 'layt4_cnt_frstlaytlstsdbr',
	  
	));
	
	$wp_customize->add_setting('laytsdbar_swapng',array(
	
	   'capability' => 'edit_theme_options',
	   'transport' => 'refresh',
	   'default' => 0,
	   'sanitize_callback' => 'absint',
	
	));
	
	$wp_customize->add_control('admania_laytsdbar_swapng_control',array(
	  
	  'type' => 'checkbox',
	  'section' => 'admania-sidebar-section',
	  'label' => esc_html__('Enable the Sidebar Swap','ad-mania'),
	  'settings' => 'laytsdbar_swapng',
	  
	));
	
	// Add post and page section,setting,control
	
	$wp_customize->add_section('admania-postandpage-section',array(
		'title' => esc_html__('Post and Page Settings','ad-mania'),
		'priority' => 18,
		'panel' => 'admania-panel-id'
	));	
			
	$wp_customize->add_setting('admania-themeoption-expand27',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_post_byline_expand_custom_control($wp_customize,'admania-themeoption-expand27',array(
        'section' => 'admania-postandpage-section', 		
		'setting' => 'admania-themeoption-expand27',		
	)));
	
	$wp_customize->add_setting('admania_dsftdimg',array(
        'capability' => 'edit_theme_options',
		'default'    => '',
		'transport' => 'postMessage',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_single_post_dsftdimg_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Show Featured Image','ad-mania'),
		'settings' => 'admania_dsftdimg',
	));
		
	$wp_customize->selective_refresh->add_partial('admania_dsftdimg', array(
       'selector' => '.admania-single-post-ftimage', 
    ));
	
	$wp_customize->add_setting('admania_ebylfp',array(
        'capability' => 'edit_theme_options',
		'default'    => '',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_single_post_ebylfp_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Hide By Line','ad-mania'),
		'settings' => 'admania_ebylfp',
	));
	
	$wp_customize->selective_refresh->add_partial('admania_ebylfp', array(
       'selector' => '.admania-entrysgbyline', 
    ));	
	
	$wp_customize->add_setting('admania_ppostedby',array(
        'capability' => 'edit_theme_options',
		'default'    => '',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_single_post_ppostedby_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Hide Posted By','ad-mania'),
		'settings' => 'admania_ppostedby',
	));
	
	$wp_customize->add_setting('admania_ppostedon',array(
        'capability' => 'edit_theme_options',
		'default'    => '',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_single_ppostedon_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Hide Posted On','ad-mania'),
		'settings' => 'admania_ppostedon',
	));	
	
	$wp_customize->add_setting('admania_ppostedtime',array(
        'capability' => 'edit_theme_options',
		'default'    => '',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_single_ppostedtime_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Hide Posted Time','ad-mania'),
		'settings' => 'admania_ppostedtime',
	));
	
	$wp_customize->add_setting('admania_pcategory',array(
        'capability' => 'edit_theme_options',
		'default'    => '',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_single_pcategory_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Hide Category','ad-mania'),
		'settings' => 'admania_pcategory',
	));
	
	$wp_customize->add_setting('admania_dsebyvw',array(
        'capability' => 'edit_theme_options',
		'default'    => '',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_single_dsebyvw_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Hide Views Count','ad-mania'),
		'settings' => 'admania_dsebyvw',
	));
	
	$wp_customize->add_setting('admania-themeoption-expand28',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_post_dft_ftdimg_expand_custom_control($wp_customize,'admania-themeoption-expand28',array(
        'section' => 'admania-postandpage-section', 		
		'setting' => 'admania-themeoption-expand28',		
	)));
	
	$wp_customize->add_setting('admania_df_postimg',array(
        'capability' => 'edit_theme_options',
		'default'    => '',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_single_df_postimg_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Show Default Featured Image','ad-mania'),
		'settings' => 'admania_df_postimg',
	));
	
	$wp_customize->add_setting('admania_df_postimg_url',array(
	  
	  'capability' => 'edit_theme_options',	  
	  'transport' => 'refresh',
	  'sanitize_callback' => 'esc_url'
	
	));
	
	$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize,'admania_df_postimg_url',array(
		'section' => 'admania-postandpage-section',
		'label' => esc_html__('Default Featured Image','ad-mania'),
		'settings' => 'admania_df_postimg_url',
	)));
	
	$wp_customize->add_setting('admania-themeoption-expand29',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_post_content_readmore_expand_custom_control($wp_customize,'admania-themeoption-expand29',array(
        'section' => 'admania-postandpage-section', 		
		'setting' => 'admania-themeoption-expand29',		
	)));
	
	$wp_customize->add_setting('admania_post_read_more',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));

	$wp_customize->add_control('admania_post_content_readmore_text_control',array(
        'type' => 'text',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Post Content Read More text','ad-mania'),
		'settings' => 'admania_post_read_more',
	));	
	
	
	$wp_customize->selective_refresh->add_partial('admania_post_read_more', array(
       'selector' => '.admania-editmore-link', 
       'render_callback' => 'admania_post_content_readmore_text'  
   ));
   
	
	
	$wp_customize->add_setting('admania-themeoption-expand30',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_page_byline_expand_custom_control($wp_customize,'admania-themeoption-expand30',array(
        'section' => 'admania-postandpage-section', 		
		'setting' => 'admania-themeoption-expand30',		
	)));
	
	$wp_customize->add_setting('admania_dspgftdimg',array(
        'capability' => 'edit_theme_options',
		'default'    => '',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_single_post_dspgftdimg_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Show Featured Image','ad-mania'),
		'settings' => 'admania_dspgftdimg',
	));
	
	
	
	$wp_customize->add_setting('admania_ebylfpage',array(
        'capability' => 'edit_theme_options',
		'default'    => '',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_single_ebylfpage_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Show By Line','ad-mania'),
		'settings' => 'admania_ebylfpage',
	));
	
	$wp_customize->selective_refresh->add_partial('admania_ebylfpage', array(
       'selector' => '.admania-entrypgebyline', 
    ));	
	
	$wp_customize->add_setting('padmania_ppostedby',array(
        'capability' => 'edit_theme_options',
		'default'    => '',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_single_post_pgpostedby_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Show Posted By','ad-mania'),
		'settings' => 'padmania_ppostedby',
	));
	
	$wp_customize->add_setting('padmania_ppostedon',array(
        'capability' => 'edit_theme_options',
		'default'    => '',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_single_pgpostedon_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Show Posted On','ad-mania'),
		'settings' => 'padmania_ppostedon',
	));	
	
	$wp_customize->add_setting('padmania_ppview',array(
        'capability' => 'edit_theme_options',
		'default'    => '',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));
	
	$wp_customize->add_control('admania_single_pgpview_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Show Views Count','ad-mania'),
		'settings' => 'padmania_ppview',
	));
	
	$wp_customize->add_setting('admania_linktype',array(
	   'capability' => 'edit_theme_options',
	   'default' => 'underline',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_key'
	));
	
	$wp_customize->add_control('admania_linktype_control',array(
	  'type' => 'select',
	  'section' => 'admania-postandpage-section',
	  'label' => esc_html__('post content link types','ad-mania'),
	  'settings' => 'admania_linktype',
	  'choices' => $admania_post_link_types
	));
	
	
	$wp_customize->add_setting('admania-themeoption-expand31',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_breadcrumb_expand_custom_control($wp_customize,'admania-themeoption-expand31',array(
        'section' => 'admania-postandpage-section', 		
		'setting' => 'admania-themeoption-expand31',		
	)));
	
	$wp_customize->add_setting('admania_breadcrumb_post',array(
        'capability' => 'edit_theme_options',
		'default'    => '',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_single_breadcrumb_post_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Show Breadcrumbs On Posts','ad-mania'),
		'settings' => 'admania_breadcrumb_post',
	));
	
	$wp_customize->selective_refresh->add_partial('admania_breadcrumb_post', array(
       'selector' => '.single .admania_breadcrumb', 
    ));
	
	$wp_customize->add_setting('admania_breadcrumb_pages',array(
        'capability' => 'edit_theme_options',
		'default'    => '',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_single_breadcrumb_pages_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Show Breadcrumbs On Pages','ad-mania'),
		'settings' => 'admania_breadcrumb_pages',
	));
	
	$wp_customize->selective_refresh->add_partial('admania_breadcrumb_pages', array(
       'selector' => '.page .admania_breadcrumb', 
    ));
	
	$wp_customize->add_setting('admania_breadcrumb_archives',array(
        'capability' => 'edit_theme_options',
		'default'    => '',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_single_breadcrumb_archives_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Show Breadcrumbs On Archives','ad-mania'),
		'settings' => 'admania_breadcrumb_archives',
	));
	
	$wp_customize->selective_refresh->add_partial('admania_breadcrumb_archives', array(
       'selector' => '.archive .admania_breadcrumb', 
    ));
	
	$wp_customize->add_setting('admania-themeoption-expand32',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_post_socialshare_expand_custom_control($wp_customize,'admania-themeoption-expand32',array(
        'section' => 'admania-postandpage-section', 		
		'setting' => 'admania-themeoption-expand32',		
	)));
	
	$wp_customize->add_setting('admania_active_postsocialshare',array(
        'capability' => 'edit_theme_options',
		'default'    => '',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_single_post_socialshare_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Show Post Social Share','ad-mania'),
		'settings' => 'admania_active_postsocialshare',
	));	
	
	$wp_customize->selective_refresh->add_partial('admania_active_postsocialshare', array(
       'selector' => '.admania-postsharecnt', 
    ));
	
	$wp_customize->add_setting('admania_postsocialfb',array(
        'capability' => 'edit_theme_options',
		'default'    => '',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_single_disable_fb_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Hide Facebook','ad-mania'),
		'settings' => 'admania_postsocialfb',
	));
	
	$wp_customize->add_setting('admania_postsocialfblike',array(
        'capability' => 'edit_theme_options',
		'default'    => '',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_single_disable_fb_like_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Hide Facebook Like Button','ad-mania'),
		'settings' => 'admania_postsocialfblike',
	));
	
	$wp_customize->add_setting('admania_postsocialtwitter',array(
        'capability' => 'edit_theme_options',
		'default'    => '',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_single_disable_twt_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Hide Twitter','ad-mania'),
		'settings' => 'admania_postsocialtwitter',
	));
	
	$wp_customize->add_setting('admania_postsocialgplus',array(
        'capability' => 'edit_theme_options',
		'default'    => '',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_single_disable_gplus_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Hide Gplus','ad-mania'),
		'settings' => 'admania_postsocialgplus',
	));
	
	$wp_customize->add_setting('admania_postsociallinkedin',array(
        'capability' => 'edit_theme_options',
		'default'    => '',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_single_disable_linkedin_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Hide Linkedin','ad-mania'),
		'settings' => 'admania_postsociallinkedin',
	));
	
	$wp_customize->add_setting('admania_postsocialpinterest',array(
        'capability' => 'edit_theme_options',
		'default'    => '',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_single_disable_pinterest_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Hide Pinterest','ad-mania'),
		'settings' => 'admania_postsocialpinterest',
	));
	
	$wp_customize->add_setting('admania_postsocialbuffer',array(
        'capability' => 'edit_theme_options',
		'default'    => '',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_single_disable_buffer_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Show Buffer','ad-mania'),
		'settings' => 'admania_postsocialbuffer',
	));
	
	$wp_customize->add_setting('admania_postsocialstumble',array(
        'capability' => 'edit_theme_options',
		'default'    => '',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_single_disable_stumbleupon_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Show Stumbleupon','ad-mania'),
		'settings' => 'admania_postsocialstumble',
	));
	
	$wp_customize->add_setting('admania_postsocialredit',array(
        'capability' => 'edit_theme_options',
		'default'    => '',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_single_disable_reddit_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Show Reddit','ad-mania'),
		'settings' => 'admania_postsocialredit',
	));
	
	$wp_customize->add_setting('admania_postsocialwhatsapp',array(
        'capability' => 'edit_theme_options',
		'default'    => '',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_single_disable_whatsapp_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Show Whatsapp','ad-mania'),
		'settings' => 'admania_postsocialwhatsapp',
	));
	
	$wp_customize->add_setting('admania-themeoption-expand33',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_relatedpost_expand_custom_control($wp_customize,'admania-themeoption-expand33',array(
        'section' => 'admania-postandpage-section', 		
		'setting' => 'admania-themeoption-expand33',		
	)));
	
	// Single relatedpost setting, relatedpost control
		
	$wp_customize->add_setting('admania-enable-related-post-by-category',array(
        'capability' => 'edit_theme_options',
		'default'    => 'category',
		'transport' => 'refresh',
        'sanitize_callback' => 'sanitize_key',
	));

	$wp_customize->add_control('admania_single_post_relatedpost_control',array(
        'type' => 'radio',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('post type ','ad-mania'),
		'settings' => 'admania-enable-related-post-by-category',
		'choices' => array(
		 'category' => esc_html__('Category','ad-mania'),
		 'tag' => esc_html__('Tag','ad-mania')
		),
	));
	
	
	$wp_customize->selective_refresh->add_partial('admania-enable-related-post-by-category', array(
       'selector' => '.admania-related-posts', 
    ));
			
	$wp_customize->add_setting('admania_choserd1',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'sanitize_key',
	));

	$wp_customize->add_control('admania_single_post_relatedpost_order_control',array(
        'type' => 'radio',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Post Order','ad-mania'),
		'settings' => 'admania_choserd1',
		'choices' => array(
		 'latest' => esc_html__('Latest','ad-mania'),
		 'random' => esc_html__('Random','ad-mania')
		),
	));	
	
	$wp_customize->add_setting('admania_relatedpostbytagcount',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh', 
        'sanitize_callback' => 'absint', // The hue is stored as a positive integer.		
	));

	$wp_customize->add_control('admania_single_post_relatedpost_count_control',array(
        'type' => 'text',		
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('post count','ad-mania'),
		'settings' => 'admania_relatedpostbytagcount',
	));
	
	$wp_customize->add_setting('admania-themeoption-expand34',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_pagination_expand_custom_control($wp_customize,'admania-themeoption-expand34',array(
        'section' => 'admania-postandpage-section', 		
		'setting' => 'admania-themeoption-expand34',		
	)));
	
	// Single next/previous post
	
	$wp_customize->add_setting('admania_snglpaginationpn',array(
        'capability' => 'edit_theme_options',
		'default'    => false,
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));
	
	$wp_customize->add_control('admania_single_post_nextprev_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Next/Prev Post','ad-mania'),
		'settings' => 'admania_snglpaginationpn',
		'description' => esc_html__('Disable Single Next/Prev Post','ad-mania'),
	    
	));
	
	$wp_customize->selective_refresh->add_partial('admania_snglpaginationpn', array(
       'selector' => '.admania-prenext', 
    ));
	
	// Home page pagination with number.
	
	$wp_customize->add_setting('admania_hmpgpaginationno',array(
        'capability' => 'edit_theme_options',
		'default'    => false,
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));
	
	$wp_customize->add_control('admania_pagination_control',array(
       
	    'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Home Pagination','ad-mania'),
		'settings' => 'admania_hmpgpaginationno',
		'description' => esc_html__('Disable Home Pagination','ad-mania'),
	    
	));
	
	$wp_customize->selective_refresh->add_partial('admania_hmpgpaginationno', array(
       'selector' => '.single .admania-pagination', 
    ));	
	
	// Home page prev/next pagination.
	
	$wp_customize->add_setting('admania_hmpgpgnextprev',array(
        'capability' => 'edit_theme_options',
		'default'    => 0,
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));
	
	$wp_customize->add_control('admania_prev_next_pagination_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Home Prev/Next Pagination','ad-mania'),
		'settings' => 'admania_hmpgpgnextprev',
		'description' => esc_html__('Enable Prev/Next Pagination','ad-mania'),
	    
	));
	
	$wp_customize->selective_refresh->add_partial('admania_hmpgpgnextprev', array(
       'selector' => '.admania-hmpageprenext', 
    ));	
	
	$wp_customize->add_setting('admania_preposttrnstxt',array(
        'capability' => 'edit_theme_options',
		'default'    => esc_html__('prev post','ad-mania'),
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));

	$wp_customize->add_control('admania_prev_text_control',array(
        'type' => 'text',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('prev post text','ad-mania'),
		'settings' => 'admania_preposttrnstxt',
		'description' => esc_html__('change your prev post text','ad-mania'),
	));
		
	$wp_customize->add_setting('admania_nxtposttrnstxt',array(
        'capability' => 'edit_theme_options',
		'default'    => esc_html__('next post','ad-mania'),
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));

	$wp_customize->add_control('admania_next_text_control',array(
        'type' => 'text',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('next post text','ad-mania'),
		'settings' => 'admania_nxtposttrnstxt',
		'description' => esc_html__('change your next post text','ad-mania'),
	));	
	
	$wp_customize->add_setting('admania-themeoption-expand35',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_comment_expand_custom_control($wp_customize,'admania-themeoption-expand35',array(
        'section' => 'admania-postandpage-section', 		
		'setting' => 'admania-themeoption-expand35',		
	)));
	
	// comment section on post
	
	$wp_customize->add_setting('admania_commentspost',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));
	
	$wp_customize->add_control('admania_comment_post_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Hide Comment on post','ad-mania'),
		'settings' => 'admania_commentspost',
		
	));
	
	$wp_customize->selective_refresh->add_partial('admania_commentspost', array(
       'selector' => '.admania-commentbox', 
    ));
	
	// comment section on page
	
	$wp_customize->add_setting('admania_commentspage',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));
	
	$wp_customize->add_control('admania_comment_page_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Hide Comment on page','ad-mania'),
		'settings' => 'admania_commentspage',
	));
	
	
	$wp_customize->selective_refresh->add_partial('admania_commentspage', array(
       'selector' => '.page .admania-commentbox', 
    ));
	
	$wp_customize->add_setting('admania-themeoption-expand36',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));

	$wp_customize->add_control(new admania_home_socialshare_expand_custom_control($wp_customize,'admania-themeoption-expand36',array(
        'section' => 'admania-postandpage-section', 		
		'setting' => 'admania-themeoption-expand36',		
	)));
	
	$wp_customize->add_setting('disable_lay1fb',array(
        'capability' => 'edit_theme_options',
		'default'    => '',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_single_disable_lay1fb_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Show Facebook Share','ad-mania'),
		'settings' => 'disable_lay1fb',
	));
	
	$wp_customize->selective_refresh->add_partial('disable_lay1fb', array(
       'selector' => '.admania-entryftrscl,.admania-ninth-post-entryscl', 
    ));
	
	$wp_customize->add_setting('disable_lay1tw',array(
        'capability' => 'edit_theme_options',
		'default'    => '',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_single_disable_lay1tw_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Show Twitter Share','ad-mania'),
		'settings' => 'disable_lay1tw',
	));
	
	$wp_customize->add_setting('disable_lay1pin',array(
        'capability' => 'edit_theme_options',
		'default'    => '',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_single_disable_lay1pin_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Show Pinterest Share','ad-mania'),
		'settings' => 'disable_lay1pin',
	));
	
	$wp_customize->add_setting('disable_lay1lnkd',array(
        'capability' => 'edit_theme_options',
		'default'    => '',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_single_disable_lay1lnkd_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Show Linkedin Share','ad-mania'),
		'settings' => 'disable_lay1lnkd',
	));
	
	$wp_customize->add_setting('disable_lay1stmble',array(
        'capability' => 'edit_theme_options',
		'default'    => '',
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_single_disable_lay1stmble_control',array(
        'type' => 'checkbox',
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Show Stumbleupon Share','ad-mania'),
		'settings' => 'disable_lay1stmble',
	));	
	
	$wp_customize->add_setting('gridpst_minhgt',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh', 
        'sanitize_callback' => 'absint', // The hue is stored as a positive integer.		
	));

	$wp_customize->add_control('admania_gridpst_minhgt_control',array(
        
		'type' => 'text',		
		'section' => 'admania-postandpage-section', 
		'label' => esc_html__('Enter the Grid Post Heading Min Height','ad-mania'),
		'settings' => 'gridpst_minhgt',
		
	));
	
	// Add Typography settings section,setting,control
	
	$wp_customize->add_section('admania-typo-settings',array(
		'title' => esc_html__('Typography Settings','ad-mania'),
		'priority' => 19,
		'panel' => 'admania-panel-id'
	));
		
	$wp_customize->add_setting('admania-themeoption-expand37',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_google_body_font_expand_custom_control($wp_customize,'admania-themeoption-expand37',array(
        'section' => 'admania-typo-settings', 		
		'setting' => 'admania-themeoption-expand37',		
	)));
	
	$wp_customize->add_setting('admania_google_body_font_setting',array(
        'capability' => 'edit_theme_options',
        'default' => esc_html__('select','ad-mania'),			
		'transport' => 'refresh',			
        'sanitize_callback' => 'sanitize_key'        
	));

	$wp_customize->add_control('admania_google_body_font_control',array(
        'type' => 'select',		
		'section' => 'admania-typo-settings', 
		'label' => esc_html__('Script/Subset(Languages)','ad-mania'),
		'settings' => 'admania_google_body_font_setting',
		'description' => esc_html__('select subset for google font family','ad-mania'),
	    'choices' => array(
		   'no-font-weight' => esc_html__('select','ad-mania'),
		   'cyrillic' => esc_html__('Cyrillic','ad-mania'),
		   'cyrillic-ext' => esc_html__('Cyrillic Extended','ad-mania'),
		   'greek'=> esc_html__('Greek','ad-mania'),
		   'greek-ext'=> esc_html__('Greek Extended','ad-mania'),
		   'latin' => esc_html__('Latin','ad-mania'),
		   'latin-ext' => esc_html__('Latin Extended','ad-mania'),
		   'vietnamese' => esc_html__('Vietnamese','ad-mania'),
		   'devanagari' => esc_html__('Devanagari','ad-mania')
		)
	));
	
	$wp_customize->add_setting('admania_bodygooglefont',array(
        'capability' => 'edit_theme_options',		
		'default' => 'Noto Sans',
		'transport' => 'refresh',		
        'sanitize_callback' => 'sanitize_text_field',
	));
	
	$wp_customize->add_control(new admania_google_font_dropdown_custom_control($wp_customize,'admania_bodygooglefont',array(
       	'section' => 'admania-typo-settings', 
		'label' => esc_html__('Font Family','ad-mania'),
		'settings' => 'admania_bodygooglefont',
		'description' => esc_html__('select font family','ad-mania'),
	)));
	
	$wp_customize->add_setting('admania_google_body_font_weight_setting',array(
        'capability' => 'edit_theme_options',	
        'default' => esc_html__('select','ad-mania'),		
		'transport' => 'refresh',	        		
        'sanitize_callback' => 'sanitize_key'        
	));

	$wp_customize->add_control('admania_google_body_font_weight_control',array(
        'type' => 'select',		
		'section' => 'admania-typo-settings', 
		'label' => esc_html__('Font Weight/Style','ad-mania'),
		'settings' => 'admania_google_body_font_weight_setting',
		'description' => esc_html__('select font weight/style','ad-mania'),
	    'choices' => array(
		   'no-font-weight' => esc_html__('select','ad-mania'),
		   '300' => esc_html__('light 300','ad-mania'),
		   '300i' => esc_html__('light 300 Italic','ad-mania'),
		   '400'=> esc_html__('regular 400','ad-mania'),
		   '400i'=> esc_html__('regular 400 Italic','ad-mania'),
		   '600' => esc_html__('semi-bold 600','ad-mania'),
		   '600i' => esc_html__('semi-bold 600 Italic','ad-mania'),
		   '700' => esc_html__('bold 700','ad-mania'),
		   '700i' => esc_html__('bold 700 Italic','ad-mania'),
		   '800' => esc_html__('extra-bold 800','ad-mania'),
		   '800i' => esc_html__('extra-bold 800 Italic','ad-mania')		   
		)
	));
	
	$wp_customize->add_setting('admania-themeoption-expand38',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_google_heading_font_expand_custom_control($wp_customize,'admania-themeoption-expand38',array(
        'section' => 'admania-typo-settings', 		
		'setting' => 'admania-themeoption-expand38',		
	)));
	
	$wp_customize->add_setting('admania_google_heading_font_setting',array(
        'capability' => 'edit_theme_options',		
		'default' => '',
		'transport' => 'refresh',		
        'sanitize_callback' => 'sanitize_key'        
	));

	$wp_customize->add_control('admania_google_heading_font_control',array(
        'type' => 'select',		
		'section' => 'admania-typo-settings', 
		'label' => esc_html__('Script/Subset(Languages)','ad-mania'),
		'settings' => 'admania_google_heading_font_setting',
		'description' => esc_html__('select subset for google font family','ad-mania'),
	    'choices' => array(
		   'no-font-weight' => esc_html__('select','ad-mania'),
		   'cyrillic' => esc_html__('Cyrillic','ad-mania'),
		   'cyrillic-ext' => esc_html__('Cyrillic Extended','ad-mania'),
		   'greek'=> esc_html__('Greek','ad-mania'),
		   'greek-ext'=> esc_html__('Greek Extended','ad-mania'),
		   'latin' => esc_html__('Latin','ad-mania'),
		   'latin-ext' => esc_html__('Latin Extended','ad-mania'),
		   'vietnamese' => esc_html__('Vietnamese','ad-mania'),
		   'devanagari' => esc_html__('Devanagari','ad-mania')
		)
	));
				
    $wp_customize->add_setting('admania_googlefont', array(
		'capability' => 'edit_theme_options',		
		'default' => 'Oswald',
		'transport' => 'refresh',		
        'sanitize_callback' => 'sanitize_text_field',
	));
	
	$wp_customize->add_control( new admania_google_font_dropdown_custom_control( $wp_customize, 'admania_googlefont', array(
		'section' => 'admania-typo-settings', 
		'label' => esc_html__('Font Family','ad-mania'),
		'settings' => 'admania_googlefont',
		'description' => esc_html__('Here, you can select site heading font family','ad-mania'),
	)));	
	
	$wp_customize->add_setting('admania_hdweight',array(
        'capability' => 'edit_theme_options',		
		'default' => esc_html__('select','ad-mania'),
		'transport' => 'refresh',       		
        'sanitize_callback' => 'sanitize_key'        
	));

	$wp_customize->add_control('admania_google_heading_font_weight_control',array(
        'type' => 'select',		
		'section' => 'admania-typo-settings', 
		'label' => esc_html__('Font Weight/Style','ad-mania'),
		'settings' => 'admania_hdweight',
		'description' => esc_html__('select font weight/style','ad-mania'),
	    'choices' => array(
		   'no-font-weight' => esc_html__('select','ad-mania'),
		   '300' => esc_html__('light 300','ad-mania'),
		   '300i' => esc_html__('light 300 Italic','ad-mania'),
		   '400'=> esc_html__('regular 400','ad-mania'),
		   '400i'=> esc_html__('regular 400 Italic','ad-mania'),
		   '600' => esc_html__('semi-bold 600','ad-mania'),
		   '600i' => esc_html__('semi-bold 600 Italic','ad-mania'),
		   '700' => esc_html__('bold 700','ad-mania'),
		   '700i' => esc_html__('bold 700 Italic','ad-mania'),
		   '800' => esc_html__('extra-bold 800','ad-mania'),
		   '800i' => esc_html__('extra-bold 800 Italic','ad-mania')		   
		)
	));
				
	$wp_customize->add_setting('admania-themeoption-expand39',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_body_font_expand_custom_control($wp_customize,'admania-themeoption-expand39',array(
        'section' => 'admania-typo-settings', 		
		'setting' => 'admania-themeoption-expand39',		
	)));
	
	// add body font size
		
	$wp_customize->add_setting('admania_body_font_setting', array(
		'capability' => 'edit_theme_options',		
		'default' => '16px',
		'transport' => 'postMessage',		
        'sanitize_callback' => 'absint',
	));
	
	$wp_customize->add_control( new admania_input_range_custom_control( $wp_customize, 'admania_body_font_setting', array(
		'section' => 'admania-typo-settings', 
		'label' => esc_html__('Font Size','ad-mania'),
		'settings' => 'admania_body_font_setting',
		'description' => esc_html__('Choose body text fontsize','ad-mania'),
	    'input_attrs' => array(
                'min' => 15,
                'max' => 100,
         ),
	)));	
	
	$wp_customize->selective_refresh->add_partial('admania_body_font_setting',array(
	   'render_callback' => 'admania_customize_partial_body_fontsize'
	));
	
	
	// add body line height
	
	$wp_customize->add_setting('lineheight', array(
		'capability' => 'edit_theme_options',		
		'default' => '25px',
		'transport' => 'postMessage',		
        'sanitize_callback' => 'absint',
	));
	
	$wp_customize->add_control( new admania_input_range_custom_control( $wp_customize, 'lineheight', array(
		'section' => 'admania-typo-settings', 
		'label' => esc_html__('Line Height','ad-mania'),
		'settings' => 'lineheight',
		'description' => esc_html__('Choose body text lineheight','ad-mania'),
	    'input_attrs' => array(
                'min' => 25,
                'max' => 100,
         ),
	)));
	
	$wp_customize->selective_refresh->add_partial('lineheight',array(
	   'render_callback' => 'admania_customize_partial_body_lineheight'
	));
		
	$wp_customize->add_setting('admania-themeoption-expand40',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_h1_font_expand_custom_control($wp_customize,'admania-themeoption-expand40',array(
        'section' => 'admania-typo-settings', 		
		'setting' => 'admania-themeoption-expand40',		
	)));
	
	// add H1 font size
		
	$wp_customize->add_setting('headeroneadmania_fontsize', array(
		'capability' => 'edit_theme_options',		
		'default' => '40px',
		'transport' => 'postMessage',		
        'sanitize_callback' => 'absint',
	));
	
	$wp_customize->add_control( new admania_input_range_custom_control( $wp_customize, 'headeroneadmania_fontsize', array(
		'section' => 'admania-typo-settings', 
		'label' => esc_html__('Font Size','ad-mania'),
		'settings' => 'headeroneadmania_fontsize',
		'description' => esc_html__('Choose H1 fontsize','ad-mania'),
	    'input_attrs' => array(
                'min' => 10,
                'max' => 100,
         ),
	)));	
	
	$wp_customize->selective_refresh->add_partial('headeroneadmania_fontsize',array(
	   'selector' => 'h1'	   
	));
	
	// add H1 line height
	
	$wp_customize->add_setting('admania_headeronelineheight', array(
		'capability' => 'edit_theme_options',		
		'default' => '47px',
		'transport' => 'postMessage',		
        'sanitize_callback' => 'absint',
	));
	
	$wp_customize->add_control( new admania_input_range_custom_control( $wp_customize, 'admania_headeronelineheight', array(
		'section' => 'admania-typo-settings', 
		'label' => esc_html__('Line Height','ad-mania'),
		'settings' => 'admania_headeronelineheight',
		'description' => esc_html__('Choose H1 lineheight','ad-mania'),
	    'input_attrs' => array(
                'min' => 15,
                'max' => 100,
         ),
	)));
	
	$wp_customize->selective_refresh->add_partial('admania_headeronelineheight',array(
	   'selector' => 'h1'	  
	));
	
	// add h1 heading text transform
			
	$wp_customize->add_setting('admania_hdonetrfrm',array(
        'capability' => 'edit_theme_options',		
		'default' => 'none',
		'transport' => 'refresh',		
        'sanitize_callback' => 'sanitize_key'        
	));

	$wp_customize->add_control('admania_heading1_text_tranform_control',array(
        'type' => 'select',		
		'section' => 'admania-typo-settings', 
		'label' => esc_html__('Text Transform','ad-mania'),
		'settings' => 'admania_hdonetrfrm',
		'description' => esc_html__('select all heading text transform','ad-mania'),
	    'choices' => $admania_texttransform_list
	));
	
	$wp_customize->add_setting('admania-themeoption-expand41',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_h2_font_expand_custom_control($wp_customize,'admania-themeoption-expand41',array(
        'section' => 'admania-typo-settings', 		
		'setting' => 'admania-themeoption-expand41',		
	)));
	
	// add h2 font size
		
	$wp_customize->add_setting('headertwoadmania_fontsize', array(
		'capability' => 'edit_theme_options',		
		'default' => '35px',
		'transport' => 'refresh',		
        'sanitize_callback' => 'absint',
	));
	
	$wp_customize->add_control( new admania_input_range_custom_control( $wp_customize, 'headertwoadmania_fontsize', array(
		'section' => 'admania-typo-settings', 
		'label' => esc_html__('Font Size','ad-mania'),
		'settings' => 'headertwoadmania_fontsize',
		'description' => esc_html__('Choose body text fontsize','ad-mania'),
	    'input_attrs' => array(
                'min' => 10,
                'max' => 100,
         ),
	)));	
	
	$wp_customize->selective_refresh->add_partial('headertwoadmania_fontsize',array(
	   'selector' => 'h2'	   
	));	
	
	// add h2 line height
	
	$wp_customize->add_setting('admania_headertwolineheight', array(
		'capability' => 'edit_theme_options',		
		'default' => '41px',
		'transport' => 'refresh',		
        'sanitize_callback' => 'absint',
	));
	
	$wp_customize->add_control( new admania_input_range_custom_control( $wp_customize, 'admania_headertwolineheight', array(
		'section' => 'admania-typo-settings', 
		'label' => esc_html__('Line Height','ad-mania'),
		'settings' => 'admania_headertwolineheight',
		'description' => esc_html__('Choose body text lineheight','ad-mania'),
	    'input_attrs' => array(
                'min' => 15,
                'max' => 100,
         ),
	)));
	
	$wp_customize->selective_refresh->add_partial('admania_headertwolineheight',array(
	   'selector' => 'h2'	  
	));	
	
	// add h2 heading text transform
			
	$wp_customize->add_setting('admania_heading2_text_tranform_setting',array(
        'capability' => 'edit_theme_options',		
		'default' => 'none',
		'transport' => 'refresh',		
        'sanitize_callback' => 'sanitize_key'        
	));

	$wp_customize->add_control('admania_heading2_text_tranform_control',array(
        'type' => 'select',		
		'section' => 'admania-typo-settings', 
		'label' => esc_html__('Text Transform','ad-mania'),
		'settings' => 'admania_heading2_text_tranform_setting',
		'description' => esc_html__('select h2 text transform','ad-mania'),
	    'choices' => $admania_texttransform_list
	));
	
	// add h3 heading  
	
	$wp_customize->add_setting('admania-themeoption-expand42',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_h3_font_expand_custom_control($wp_customize,'admania-themeoption-expand42',array(
        'section' => 'admania-typo-settings', 		
		'setting' => 'admania-themeoption-expand42',		
	)));
	
	// add h3 font size
		
	$wp_customize->add_setting('headerthreeadmania_fontsize', array(
		'capability' => 'edit_theme_options',		
		'default' => '30px',
		'transport' => 'refresh',		
        'sanitize_callback' => 'absint',
	));
	
	$wp_customize->add_control( new admania_input_range_custom_control( $wp_customize, 'admania_h3fontsize_setting', array(
		'section' => 'admania-typo-settings', 
		'label' => esc_html__('Font Size','ad-mania'),
		'settings' => 'headerthreeadmania_fontsize',
		'description' => esc_html__('Choose body text fontsize','ad-mania'),
	    'input_attrs' => array(
                'min' => 10,
                'max' => 100,
         ),
	)));	
	
	$wp_customize->selective_refresh->add_partial('admania_h3fontsize_setting',array(
	   'selector' => 'h3'	   
	));	
	
	// add h3 line height
	
	$wp_customize->add_setting('admania_headerthreelineheight', array(
		'capability' => 'edit_theme_options',		
		'default' => '39px',
		'transport' => 'refresh',		
        'sanitize_callback' => 'absint',
	));
	
	$wp_customize->add_control( new admania_input_range_custom_control( $wp_customize, 'admania_headerthreelineheight', array(
		'section' => 'admania-typo-settings', 
		'label' => esc_html__('Line Height','ad-mania'),
		'settings' => 'admania_headerthreelineheight',
		'description' => esc_html__('Choose body text lineheight','ad-mania'),
	    'input_attrs' => array(
                'min' => 15,
                'max' => 100,
         ),
	)));
	
	$wp_customize->selective_refresh->add_partial('admania_headerthreelineheight',array(
	   'selector' => 'h3'	  
	));
		
	// add heading h3 text transform
			
	$wp_customize->add_setting('admania_heading3_text_tranform_setting',array(
        'capability' => 'edit_theme_options',		
		'default' => 'none',
		'transport' => 'refresh',		
        'sanitize_callback' => 'sanitize_key'        
	));

	$wp_customize->add_control('admania_heading3_text_tranform_control',array(
        'type' => 'select',		
		'section' => 'admania-typo-settings', 
		'label' => esc_html__('Text Transform','ad-mania'),
		'settings' => 'admania_heading3_text_tranform_setting',
		'description' => esc_html__('select h3 text transform','ad-mania'),
	    'choices' => $admania_texttransform_list
	));
	
	$wp_customize->add_setting('admania-themeoption-expand43',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_h4_font_expand_custom_control($wp_customize,'admania-themeoption-expand43',array(
        'section' => 'admania-typo-settings', 		
		'setting' => 'admania-themeoption-expand43',		
	)));
	
	// add h4 font size
		
	$wp_customize->add_setting('headerfouradmania_fontsize', array(
		'capability' => 'edit_theme_options',		
		'default' => '28px',
		'transport' => 'refresh',		
        'sanitize_callback' => 'absint',
	));
	
	$wp_customize->add_control( new admania_input_range_custom_control( $wp_customize, 'headerfouradmania_fontsize', array(
		'section' => 'admania-typo-settings', 
		'label' => esc_html__('Font Size','ad-mania'),
		'settings' => '6',
		'description' => esc_html__('Choose h4 fontsize','ad-mania'),
	    'input_attrs' => array(
                'min' => 10,
                'max' => 100,
         ),
	)));	
		
	$wp_customize->selective_refresh->add_partial('headerfouradmania_fontsize',array(
	   'selector' => 'h4'	   
	));	
	
	
	
	// add h4 line height
	
	$wp_customize->add_setting('admania_headerfourlineheight', array(
		'capability' => 'edit_theme_options',		
		'default' => '32px',
		'transport' => 'refresh',		
        'sanitize_callback' => 'absint',
	));
	
	$wp_customize->add_control( new admania_input_range_custom_control( $wp_customize, 'admania_headerfourlineheight', array(
		'section' => 'admania-typo-settings', 
		'label' => esc_html__('Line Height','ad-mania'),
		'settings' => 'admania_headerfourlineheight',
		'description' => esc_html__('Choose h4 lineheight','ad-mania'),
	    'input_attrs' => array(
                'min' => 16,
                'max' => 100,
         ),
	)));
	
	$wp_customize->selective_refresh->add_partial('admania_headerfourlineheight',array(
	   'selector' => 'h4'	  
	));	
	
	// add heading h4 text transform
			
	$wp_customize->add_setting('admania_heading4_text_tranform_setting',array(
        'capability' => 'edit_theme_options',		
		'default' => 'none',
		'transport' => 'refresh',		
        'sanitize_callback' => 'sanitize_key'        
	));

	$wp_customize->add_control('admania_heading4_text_tranform_control',array(
        'type' => 'select',		
		'section' => 'admania-typo-settings', 
		'label' => esc_html__('Text Transform','ad-mania'),
		'settings' => 'admania_heading4_text_tranform_setting',
		'description' => esc_html__('select h4 text transform','ad-mania'),
	    'choices' => $admania_texttransform_list
	));
	
	$wp_customize->add_setting('admania-themeoption-expand44',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_h5_font_expand_custom_control($wp_customize,'admania-themeoption-expand44',array(
        'section' => 'admania-typo-settings', 		
		'setting' => 'admania-themeoption-expand44',		
	)));
	
	// add h5 font size
		
	$wp_customize->add_setting('headerfiveadmania_fontsize', array(
		'capability' => 'edit_theme_options',		
		'default' => '24px',
		'transport' => 'refresh',		
        'sanitize_callback' => 'absint',
	));
	
	$wp_customize->add_control( new admania_input_range_custom_control( $wp_customize, 'headerfiveadmania_fontsize', array(
		'section' => 'admania-typo-settings', 
		'label' => esc_html__('Font Size','ad-mania'),
		'settings' => 'headerfiveadmania_fontsize',
		'description' => esc_html__('Choose h5 fontsize','ad-mania'),
	    'input_attrs' => array(
                'min' => 10,
                'max' => 100,
         ),
	)));	
	

	$wp_customize->selective_refresh->add_partial('headerfiveadmania_fontsize',array(
	   'selector' => 'h5'	   
	));	
	
	
	
	// add h5 line height
	
	$wp_customize->add_setting('admania_headerfivelineheight', array(
		'capability' => 'edit_theme_options',		
		'default' => '30px',
		'transport' => 'refresh',		
        'sanitize_callback' => 'absint',
	));
	
	$wp_customize->add_control( new admania_input_range_custom_control( $wp_customize, 'admania_headerfivelineheight', array(
		'section' => 'admania-typo-settings', 
		'label' => esc_html__('Line Height','ad-mania'),
		'settings' => 'admania_headerfivelineheight',
		'description' => esc_html__('Choose h5 lineheight','ad-mania'),
	    'input_attrs' => array(
                'min' => 16,
                'max' => 100,
         ),
	)));
	
	$wp_customize->selective_refresh->add_partial('admania_headerfivelineheight',array(
	   'selector' => 'h5'	  
	));
	
	$wp_customize->add_setting('admania_heading5_text_tranform_setting',array(
        'capability' => 'edit_theme_options',		
		'default' => 'none',
		'transport' => 'refresh',		
        'sanitize_callback' => 'sanitize_key'        
	));

	$wp_customize->add_control('admania_heading5_text_tranform_control',array(
        'type' => 'select',		
		'section' => 'admania-typo-settings', 
		'label' => esc_html__('Text Transform','ad-mania'),
		'settings' => 'admania_heading5_text_tranform_setting',
		'description' => esc_html__('select h5 text transform','ad-mania'),
	    'choices' => $admania_texttransform_list
	));
	
	$wp_customize->add_setting('admania-themeoption-expand45',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_h6_font_expand_custom_control($wp_customize,'admania-themeoption-expand45',array(
        'section' => 'admania-typo-settings', 		
		'setting' => 'admania-themeoption-expand45',		
	)));
		
	// add h6 font size
		
	$wp_customize->add_setting('headersixadmania_fontsize', array(
		'capability' => 'edit_theme_options',		
		'default' => '20px',
		'transport' => 'refresh',		
        'sanitize_callback' => 'absint',
	));
	
	$wp_customize->add_control( new admania_input_range_custom_control( $wp_customize, 'headersixadmania_fontsize', array(
		'section' => 'admania-typo-settings', 
		'label' => esc_html__('Font Size','ad-mania'),
		'settings' => 'headersixadmania_fontsize',
		'description' => esc_html__('Choose h6 fontsize','ad-mania'),
	    'input_attrs' => array(
                'min' => 10,
                'max' => 100,
         ),
	)));	
		
	$wp_customize->selective_refresh->add_partial('headersixadmania_fontsize',array(
	   'selector' => 'h6'	   
	));	
	
	// add h6 line height
	
	$wp_customize->add_setting('admania_headersixlineheight', array(
		'capability' => 'edit_theme_options',		
		'default' => '28px',
		'transport' => 'refresh',		
        'sanitize_callback' => 'absint',
	));
	
	$wp_customize->add_control( new admania_input_range_custom_control( $wp_customize, 'admania_headersixlineheight', array(
		'section' => 'admania-typo-settings', 
		'label' => esc_html__('Line Height','ad-mania'),
		'settings' => 'admania_headersixlineheight',
		'description' => esc_html__('Choose h6 lineheight','ad-mania'),
	    'input_attrs' => array(
                'min' => 16,
                'max' => 100,
         ),
	)));
	
	$wp_customize->selective_refresh->add_partial('admania_headersixlineheight',array(
	   'selector' => 'h6'	  
	));
	
	$wp_customize->add_setting('admania_heading6_text_tranform_setting',array(
        'capability' => 'edit_theme_options',		
		'default' => 'none',
		'transport' => 'refresh',		
        'sanitize_callback' => 'sanitize_key'        
	));

	$wp_customize->add_control('admania_heading6_text_tranform_control',array(
        'type' => 'select',		
		'section' => 'admania-typo-settings', 
		'label' => esc_html__('Text Transform','ad-mania'),
		'settings' => 'admania_heading6_text_tranform_setting',
		'description' => esc_html__('select h6 text transform','ad-mania'),
	    'choices' => $admania_texttransform_list
	));
	
	// Add Newsletter settings section,setting,control
	
	$wp_customize->add_section('admania-newsletter-settings',array(
		'title' => esc_html__('Newsletter Settings','ad-mania'),
		'priority' => 20,
		'panel' => 'admania-panel-id'
	));
		
	
	$wp_customize->add_setting('admania-themeoption-expand46',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_newsletter_post_expand_custom_control($wp_customize,'admania-themeoption-expand46',array(
        'section' => 'admania-newsletter-settings', 		
		'setting' => 'admania-themeoption-expand46',		
	)));
		
	$wp_customize->add_setting('admania_postoptincodechk',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_newsletter_control',array(
        'type' => 'checkbox',
		'section' => 'admania-newsletter-settings', 
		'label' => esc_html__('Enable newsletter','ad-mania'),
		'settings' => 'admania_postoptincodechk',
		'description' => esc_html__('Here, you can enable newsletter','ad-mania'),
	));
	
	$wp_customize->selective_refresh->add_partial('admania_postoptincodechk', array(
       'selector' => '.admania-postoptionbox', 
    ));
	
	$wp_customize->add_setting('admania_postoptincode',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'wp_kses_stripslashes',
	));

	$wp_customize->add_control(new admania_news_letter_custom_control($wp_customize,'admania_postoptincode',array(
        'section' => 'admania-newsletter-settings', 
		'label' => esc_html__('Html Optin Code','ad-mania'),
		'settings' => 'admania_postoptincode',
		'description' => esc_html__('Here, you can paste your html optin code','ad-mania'),
	)));
	
	$wp_customize->add_setting('admania_postoptinheading',array(
	  'capability' => 'edit_theme_options',
	  'transport' => 'postMessage',
	  'sanitize_callback' => 'esc_html'
	));
	
	$wp_customize->add_control('admania_newsletter_heading_control',array(
        'type' => 'text',
		'section' => 'admania-newsletter-settings', 
		'label' => esc_html__('Newsletter Title1','ad-mania'),
		'settings' => 'admania_postoptinheading',
		'description' => esc_html__('Here, you can change your heading text','ad-mania'),
	));
	
	$wp_customize->add_setting('admania_postoptinheading2',array(
	  'capability' => 'edit_theme_options',
	  'transport' => 'refresh',
	  'sanitize_callback' => 'esc_html'
	));
	
	$wp_customize->add_control('admania_newsletter_paratext_control',array(
        'type' => 'textarea',
		'section' => 'admania-newsletter-settings', 
		'label' => esc_html__('Newsletter Short Description','ad-mania'),
		'settings' => 'admania_postoptinheading2',
		'description' => esc_html__('Here, you can change your sub heading text','ad-mania'),
	));
	
	$wp_customize->add_setting('admania_postoptintypename',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));

	$wp_customize->add_control(new admania_post_news_letter_name_custom_control($wp_customize,'admania_postoptintypename',array(
        'section' => 'admania-newsletter-settings', 
		'label' => esc_html__('Name','ad-mania'),
		'settings' => 'admania_postoptintypename',
		'description' => esc_html__('Here, you can get your newsletter name from the optin code','ad-mania'),
	)));
	
	$wp_customize->add_setting('admania_postoptintypeplaceholdername',array(
        'capability' => 'edit_theme_options',
		'default'    => esc_html__('Enter your name','ad-mania'),
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));

	$wp_customize->add_control('admania_newsletter_name_placeholder_control',array(
        'type' => 'text',
		'section' => 'admania-newsletter-settings', 
		'label' => esc_html__('name placeholder','ad-mania'),
		'settings' => 'admania_postoptintypeplaceholdername',
		'description' => esc_html__('Here, you can change your input name placeholder','ad-mania'),
	));
		
	$wp_customize->add_setting('admania_postoptintypeemail',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));

	$wp_customize->add_control(new admania_post_news_letter_email_custom_control($wp_customize,'admania_postoptintypeemail',array(
        'section' => 'admania-newsletter-settings', 
		'label' => esc_html__('Email','ad-mania'),
		'settings' => 'admania_postoptintypeemail',
		'description' => esc_html__('Here, you can get your newsletter email from the optin code','ad-mania'),
	)));
	
	$wp_customize->add_setting('admania_postoptintypeplaceholderemail',array(
        'capability' => 'edit_theme_options',
		'default'    => esc_html__('Enter Your Email','ad-mania'),
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));

	$wp_customize->add_control('admania_newsletter_email_placeholder_control',array(
        'type' => 'text',
		'section' => 'admania-newsletter-settings', 
		'label' => esc_html__('email placeholder','ad-mania'),
		'settings' => 'admania_postoptintypeplaceholderemail',
		'description' => esc_html__('Here, you can change your input email placeholder','ad-mania'),
	));
	
	
	
	$wp_customize->add_setting('admania_postoptintypehidden',array(
	   'capability' => 'edit_theme_options',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'wp_kses_stripslashes',
	));
	
	$wp_customize->add_control(new admania_news_letter_hidden_custom_control($wp_customize,'admania_postoptintypehidden',array(
	    'section' => 'admania-newsletter-settings',
		'label' => esc_html__('Hidden Fields','ad-mania'),
		'settings' => 'admania_postoptintypehidden',
		'description' => esc_html__('Here, you will get the hidden fields from your optin code','ad-mania'),
	)));
	
	$wp_customize->add_setting('admania_postoptintypeurl',array(
	   'capability' => 'edit_theme_options',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'esc_url',
	));
	
	$wp_customize->add_control(new admania_news_letter_url_custom_control($wp_customize,'admania_postoptintypeurl',array(
	    'section' => 'admania-newsletter-settings',
		'label' => esc_html__('Action Url','ad-mania'),
		'settings' => 'admania_postoptintypeurl',
		'description' => esc_html__('Here, you will get the url field from your optin code','ad-mania'),
	)));	
	
	$wp_customize->add_setting('admania_postoptintypesubmit',array(
	  'capability' => 'edit_theme_options',
	  'transport' => 'postMessage',
	  'sanitize_callback' => 'esc_html'
	));
	
	$wp_customize->add_control('admania_newsletter_post_submit_control',array(
        'type' => 'text',
		'section' => 'admania-newsletter-settings', 
		'label' => esc_html__('Submit Button Name','ad-mania'),
		'settings' => 'admania_postoptintypesubmit',
		'description' => esc_html__('Here, you can change submit button name','ad-mania'),
	));
	
	$wp_customize->add_setting('admania-themeoption-expand47',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_nth_newsletter_post_expand_custom_control($wp_customize,'admania-themeoption-expand47',array(
        'section' => 'admania-newsletter-settings', 		
		'setting' => 'admania-themeoption-expand47',		
	)));
		
	$wp_customize->add_setting('admania_article_newsletter_check',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_nth_newsletter_control',array(
        'type' => 'checkbox',
		'section' => 'admania-newsletter-settings', 
		'label' => esc_html__('Enable newsletter','ad-mania'),
		'settings' => 'admania_article_newsletter_check',
		'description' => esc_html__('Here, you can enable newsletter','ad-mania'),
	));
	
	$wp_customize->add_setting('admania_article_newsletter_html_setting',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'wp_kses_stripslashes',
	));

	$wp_customize->add_control(new admania_nth_html_news_letter_custom_control($wp_customize,'admania_article_newsletter_html_setting',array(
        'section' => 'admania-newsletter-settings', 
		'label' => esc_html__('Html Optin Code','ad-mania'),
		'settings' => 'admania_article_newsletter_html_setting',
		'description' => esc_html__('Here, you can paste your html optin code','ad-mania'),
	)));
	
	
	$wp_customize->add_setting('admania_article_newsletter_heading_setting',array(
	  'capability' => 'edit_theme_options',
	  'transport' => 'refresh',
	  'sanitize_callback' => 'esc_html'
	));
	
	$wp_customize->add_control('admania_nth_newsletter_heading_control',array(
        'type' => 'text',
		'section' => 'admania-newsletter-settings', 
		'label' => esc_html__('Newsletter Title1','ad-mania'),
		'settings' => 'admania_article_newsletter_heading_setting',
		'description' => esc_html__('Here, you can change your heading text','ad-mania'),
	));
	
	$wp_customize->add_setting('admania_article_newsletter_paratext_setting',array(
	  'capability' => 'edit_theme_options',
	  'transport' => 'refresh',
	  'sanitize_callback' => 'esc_html'
	));
	
	$wp_customize->add_control('admania_nth_newsletter_paratext_control',array(
        'type' => 'textarea',
		'section' => 'admania-newsletter-settings', 
		'label' => esc_html__('Newsletter Short Description','ad-mania'),
		'settings' => 'admania_article_newsletter_paratext_setting',
		'description' => esc_html__('Here, you can change your sub heading text','ad-mania'),
	));
	
	$wp_customize->add_setting('admania_article_newsletter_email',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));

	$wp_customize->add_control(new admania_nth_post_news_letter_email_custom_control($wp_customize,'admania_article_newsletter_email',array(
        'section' => 'admania-newsletter-settings', 
		'label' => esc_html__('Email','ad-mania'),
		'settings' => 'admania_article_newsletter_email',
		'description' => esc_html__('Here, you can get your newsletter email from the optin code','ad-mania'),
	)));
	
	$wp_customize->add_setting('admania_article_newsletter_email_placeholder_setting',array(
        'capability' => 'edit_theme_options',
		'default'    => esc_html__('Enter Your Email','ad-mania'),
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));

	$wp_customize->add_control('admania_nth_newsletter_email_placeholder_control',array(
        'type' => 'text',
		'section' => 'admania-newsletter-settings', 
		'label' => esc_html__('email placeholder','ad-mania'),
		'settings' => 'admania_article_newsletter_email_placeholder_setting',
		'description' => esc_html__('Here, you can change your input email placeholder','ad-mania'),
	));
	
	$wp_customize->add_setting('admania_article_newsletter_hidden_setting',array(
	   'capability' => 'edit_theme_options',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'wp_kses_stripslashes',
	));
	
	$wp_customize->add_control(new admania_nth_news_letter_hidden_custom_control($wp_customize,'admania_article_newsletter_hidden_setting',array(
	    'section' => 'admania-newsletter-settings',
		'label' => esc_html__('Hidden Fields','ad-mania'),
		'settings' => 'admania_article_newsletter_hidden_setting',
		'description' => esc_html__('Here, you will get the hidden fields from your optin code','ad-mania'),
	)));
	
	$wp_customize->add_setting('admania_article_newsletter_url',array(
	   'capability' => 'edit_theme_options',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'esc_url',
	));
	
	$wp_customize->add_control(new admania_nth_news_letter_url_custom_control($wp_customize,'admania_article_newsletter_url',array(
	    'section' => 'admania-newsletter-settings',
		'label' => esc_html__('Action Url','ad-mania'),
		'settings' => 'admania_article_newsletter_url',
		'description' => esc_html__('Here, you will get the url field from your optin code','ad-mania'),
	)));
	
	$wp_customize->add_setting('admania_newsletter_count_setting',array(
        'capability' => 'edit_theme_options',
		'default'    => '3',
		'transport' => 'refresh', 
        'sanitize_callback' => 'absint', // The hue is stored as a positive integer.		
	));

	$wp_customize->add_control('admania_nth_post_optin_count_control',array(
        'type' => 'text',		
		'section' => 'admania-newsletter-settings', 
		'label' => esc_html__('optin post count','ad-mania'),
		'settings' => 'admania_newsletter_count_setting',
		'description' => esc_html__('enter optin nth post count','ad-mania'),
	));
	
	$wp_customize->add_section('admania-mobile-settings',array(
		'title' => esc_html__('Mobile & AMP Settings','ad-mania'),
		'priority' => 22,
		'panel' => 'admania-panel-id'
	));
			
	$wp_customize->add_setting('admania-themeoption-expand48',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
		
	$wp_customize->add_control(new admania_mobile_expand_custom_control($wp_customize,'admania-themeoption-expand48',array(
        'section' => 'admania-mobile-settings', 		
		'setting' => 'admania-themeoption-expand48',		
	)));
		
	$wp_customize->add_setting('admania_enamplayout',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_enamplayout_control',array(
        'type' => 'checkbox',
		'section' => 'admania-mobile-settings', 
		'label' => esc_html__('Disable Amp Layout','ad-mania'),
		'settings' => 'admania_enamplayout',
		'description' => esc_html__('Here, you can disable amp','ad-mania'),
	));
	
	$wp_customize->add_setting('admania_enmblayout',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_enmblayout_control',array(
        'type' => 'checkbox',
		'section' => 'admania-mobile-settings', 
		'label' => esc_html__('Enable Mobile Layout','ad-mania'),
		'settings' => 'admania_enmblayout',
		'description' => esc_html__('Here, you can enable mobile','ad-mania'),
	));
	
	$wp_customize->add_setting('admania_shw_sidebar_mblyt',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_shw_sidebar_mblyt_control',array(
        'type' => 'checkbox',
		'section' => 'admania-mobile-settings', 
		'label' => esc_html__('Show Sidebar On Mobile Layout','ad-mania'),
		'settings' => 'admania_shw_sidebar_mblyt',
		'description' => esc_html__('Here, you can show sidebar on mobile layout','ad-mania'),
	));
	
	$wp_customize->add_setting('admania_mbcustom_logo_activestatus',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'absint',
	));

	$wp_customize->add_control('admania_mbcustom_logo_activestatus_control',array(
        'type' => 'checkbox',
		'section' => 'admania-mobile-settings', 
		'label' => esc_html__('Show mobile custom Logo','ad-mania'),
		'settings' => 'admania_mbcustom_logo_activestatus',
		'description' => esc_html__('Here, you can show mobile custom logo','ad-mania'),
	));
			
	$wp_customize->add_setting('admania_mbcustom_logo',array(
	  'capability' => 'edit_theme_options',	  
	  'transport' => 'refresh',
	  'sanitize_callback' => 'esc_url'	
	));
	
	$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize,'admania_mbcustom_logo',array(
		'section' => 'admania-mobile-settings',
		'label' => esc_html__('Mobile Logo','ad-mania'),
		'settings' => 'admania_mbcustom_logo',
	)));
	
	$wp_customize->add_section('admania-footer-settings',array(
		'title' => esc_html__('Footer Section','ad-mania'),
		'priority' => 23,
		'panel' => 'admania-panel-id'
	));
		
	$wp_customize->add_setting('admania-themeoption-expand50',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_instagram4_act_expand_custom_control($wp_customize,'admania-themeoption-expand50',array(
        'section' => 'admania-footer-settings', 		
		'setting' => 'admania-themeoption-expand50',		
	)));
			
	// Add instagram section,setting,control 
	
	$wp_customize->add_setting('admania_custom_instagramact',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',       	
        'sanitize_callback' => 'absint'		
	));

	$wp_customize->add_control('admania_instagram4_act_control',array(
        'type' => 'checkbox',		
		'section' => 'admania-footer-settings', 
		'label' => esc_html__('Instagram','ad-mania'),
		'settings' => 'admania_custom_instagramact',
		'description' => esc_html__('Enable the Instagram','ad-mania'),
	));
	
	$wp_customize->selective_refresh->add_partial('admania_custom_instagramact', array(
       'selector' => '.admania-footerinstagram1', 
    ));
	
	$wp_customize->add_setting('admania_ftrinstagramusername',array(
	  'capability' => 'edit_theme_options',
	  'default' => esc_html__('Instagram @ admania','ad-mania'),
	  'transport' => 'refresh',
	  'sanitize_callback' => 'esc_html'
	));
	
	$wp_customize->add_control('admania_instagram_title_control',array(
        'type' => 'text',
		'section' => 'admania-footer-settings', 
		'label' => esc_html__('Instagram @ admania','ad-mania'),
		'settings' => 'admania_ftrinstagramusername',
		'description' => esc_html__('Enter your Instagram','ad-mania'),
	));
	
	$wp_customize->add_setting('admania_custom_insimg1',array(
	  'capability' => 'edit_theme_options',
	  'default' => '#',
	  'transport' => 'refresh',
	  'sanitize_callback' => 'esc_url'
	));
	
	$wp_customize->add_control('admania_instagram_title_url2_control',array(
        'type' => 'text',
		'section' => 'admania-footer-settings', 
		'label' => esc_html__('Instagram url','ad-mania'),
		'settings' => 'admania_custom_insimg1',
		'description' => esc_html__('Enter your instagram url','ad-mania'),
	));
	
	$wp_customize->add_setting('admania_custom_insimg1',array(
	  
	  'capability' => 'edit_theme_options',	  
	  'transport' => 'refresh',
	  'sanitize_callback' => 'esc_url'
	
	));
	
	$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize,'admania_custom_insimg1',array(
		'section' => 'admania-footer-settings',
		'label' => esc_html__('Footer Instagram Image1','ad-mania'),
		'settings' => 'admania_custom_insimg1',
		'description' => esc_html__('Here, you can change your footer Instagram Image1','ad-mania'),
	)));
			
	$wp_customize->add_setting('admania_custom_insimg2',array(
	  
	  'capability' => 'edit_theme_options',	  
	  'transport' => 'refresh',
	  'sanitize_callback' => 'esc_url'
	
	));
	
	$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize,'admania_custom_insimg2',array(
		'section' => 'admania-footer-settings',
		'label' => esc_html__('Footer Instagram Image2','ad-mania'),
		'settings' => 'admania_custom_insimg2',
		'description' => esc_html__('Here, you can change your footer Instagram Image2','ad-mania'),
	)));
	
    $wp_customize->add_setting('admania_custom_insimg3',array(
	  
	  'capability' => 'edit_theme_options',	  
	  'transport' => 'refresh',
	  'sanitize_callback' => 'esc_url'
	
	));
	
	$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize,'admania_custom_insimg3',array(
		'section' => 'admania-footer-settings',
		'label' => esc_html__('Footer Instagram Image3','ad-mania'),
		'settings' => 'admania_custom_insimg3',
		'description' => esc_html__('Here, you can change your footer Instagram Image3','ad-mania'),
	)));
	
	$wp_customize->add_setting('admania_custom_insimg4',array(
	  
	  'capability' => 'edit_theme_options',	  
	  'transport' => 'refresh',
	  'sanitize_callback' => 'esc_url'
	
	));
	
	$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize,'admania_custom_insimg4',array(
		'section' => 'admania-footer-settings',
		'label' => esc_html__('Footer Instagram Image4','ad-mania'),
		'settings' => 'admania_custom_insimg4',
		'description' => esc_html__('Here, you can change your footer Instagram Image4','ad-mania'),
	)));
	
	
	$wp_customize->add_setting('admania_custom_insimg5',array(
	  
	  'capability' => 'edit_theme_options',	  
	  'transport' => 'refresh',
	  'sanitize_callback' => 'esc_url'
	
	));
	
	$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize,'admania_custom_insimg5',array(
		'section' => 'admania-footer-settings',
		'label' => esc_html__('Footer Instagram Image5','ad-mania'),
		'settings' => 'admania_custom_insimg5',
		'description' => esc_html__('Here, you can change your footer Instagram Image5','ad-mania'),
	)));
	
	$wp_customize->add_setting('admania_custom_insimg6',array(
	  
	  'capability' => 'edit_theme_options',	  
	  'transport' => 'refresh',
	  'sanitize_callback' => 'esc_url'
	
	));
	
	$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize,'admania_custom_insimg6',array(
		'section' => 'admania-footer-settings',
		'label' => esc_html__('Footer Instagram Image6','ad-mania'),
		'settings' => 'admania_custom_insimg6',
		'description' => esc_html__('Here, you can change your footer Instagram Image6','ad-mania'),
	)));
	
	$wp_customize->add_setting('admania_custom_insimg7',array(
	  
	  'capability' => 'edit_theme_options',	  
	  'transport' => 'refresh',
	  'sanitize_callback' => 'esc_url'
	
	));
	
	$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize,'admania_custom_insimg7',array(
		'section' => 'admania-footer-settings',
		'label' => esc_html__('Footer Instagram Image7','ad-mania'),
		'settings' => 'admania_custom_insimg7',
		'description' => esc_html__('Here, you can change your footer Instagram Image7','ad-mania'),
	)));
	
	$wp_customize->add_setting('admania_custom_insimg8',array(
	  
	  'capability' => 'edit_theme_options',	  
	  'transport' => 'refresh',
	  'sanitize_callback' => 'esc_url'
	
	));
	
	$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize,'admania_custom_insimg8',array(
		'section' => 'admania-footer-settings',
		'label' => esc_html__('Footer Instagram Image8','ad-mania'),
		'settings' => 'admania_custom_insimg8',
		'description' => esc_html__('Here, you can change your footer Instagram Image8','ad-mania'),
	)));
		
	$wp_customize->add_setting('admania-themeoption-expand51',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_ftrcustomlogo_expand_custom_control($wp_customize,'admania-themeoption-expand51',array(
        'section' => 'admania-footer-settings', 		
		'setting' => 'admania-themeoption-expand51',		
	)));
	
			
	$wp_customize->add_setting('admania_ftrcustomlogo',array(
	  
	  'capability' => 'edit_theme_options',	  
	  'transport' => 'refresh',
	  'sanitize_callback' => 'esc_url'
	
	));
	
	$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize,'admania_ftrcustomlogo',array(
		'section' => 'admania-footer-settings',
		'label' => esc_html__('Footer Logo','ad-mania'),
		'settings' => 'admania_ftrcustomlogo',
		'description' => esc_html__('Here, you can change your footer logo','ad-mania'),
	)));
	
	
	$wp_customize->selective_refresh->add_partial('admania_ftrcustomlogo', array(
       'selector' => '.admania-sitefooterlogo', 
    ));
	
	$wp_customize->add_setting('admania_ftrsitetit_active',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',       	
        'sanitize_callback' => 'absint'		
	));

	$wp_customize->add_control('admania_dsbftr_act_control',array(
        'type' => 'checkbox',		
		'section' => 'admania-footer-settings', 
		'label' => esc_html__('Disable Footer Site Title','ad-mania'),
		'settings' => 'admania_ftrsitetit_active',
	));
	
	
	$wp_customize->add_control(new admania_footer_copyrights_expand_custom_control($wp_customize,'admania-themeoption-expand53',array(
        'section' => 'admania-footer-settings', 		
		'setting' => 'admania-themeoption-expand53',		
	)));
		
	$wp_customize->add_setting('admania_focopyrightscontent',array(
        'capability' => 'edit_theme_options',
		'default' => esc_html__('Admania 2019. All Rights Reserved.','ad-mania'),
		'transport' => 'refresh',		
        'sanitize_callback' => 'esc_textarea',
	));

	$wp_customize->add_control('admania_footer_copyrights_control',array(
        'type' => 'textarea',
		'section' => 'admania-footer-settings', 
		'label' => esc_html__('copy rights text','ad-mania'),
		'settings' => 'admania_focopyrightscontent',
		'description' => esc_html__('Here, you can also change your footer copy rights text','ad-mania'),
	));
   
     $wp_customize->selective_refresh->add_partial('admania_focopyrightscontent', array(
       'selector' => '.admania-ftrattbtonbottom', 
    ));
   
   	$wp_customize->add_setting('admania-themeoption-expand53',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_html',
	));
	
	$wp_customize->add_control(new admania_footer_social_expand_custom_control($wp_customize,'admania-themeoption-expand53',array(
        'section' => 'admania-footer-settings', 		
		'setting' => 'admania-themeoption-expand53',		
	)));		
	
	// Add footer Social Networks Section, Setting, Control.
	
	$wp_customize->add_setting('admania_ftrfacebook',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_url',
	));

	$wp_customize->add_control('admania_footer_social_fb_control',array(
        'type' => 'url',
		'section' => 'admania-footer-settings', 
		'label' => esc_html__('Facebook Url ','ad-mania'),
		'settings' => 'admania_ftrfacebook',
		'description' => esc_html__('paste your facebook url','ad-mania'),
	));
	
	$wp_customize->selective_refresh->add_partial('admania_ftrfacebook', array(
       'selector' => '.admania-ftrattbtontop .admania-fbflw', 
    ));
	
	$wp_customize->add_setting('admania_ftrtwitter',array(
        'capability' => 'edit_theme_options',
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_url',
	));
	
	$wp_customize->add_control('admania_footer_social_twitter_control',array(
        'type' => 'url',
		'section' => 'admania-footer-settings', 
		'label' => esc_html__('Twitter url ','ad-mania'),
		'settings' => 'admania_ftrtwitter',
		'description' => esc_html__('paste your twitter url','ad-mania'),
	));
	
	$wp_customize->selective_refresh->add_partial('admania_ftrtwitter', array(
       'selector' => '.admania-ftrattbtontop .admania-twtflw', 
    ));
			
	$wp_customize->add_setting('admania_ftrgoogleplus',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_url',
	));
	
	$wp_customize->add_control('admania_footer_social_gplus_control',array(
        'type' => 'url',
		'section' => 'admania-footer-settings', 
		'label' => esc_html__('Googleplus url ','ad-mania'),
		'settings' => 'admania_ftrgoogleplus',
		'description' => esc_html__('paste your googleplus url','ad-mania'),
	));
		
	$wp_customize->selective_refresh->add_partial('admania_ftrgoogleplus', array(
       'selector' => '.admania-ftrattbtontop .admania-gleflw', 
    ));
	
	$wp_customize->add_setting('admania_ftrlinkedin',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_url',
	));
	
	$wp_customize->add_control('admania_footer_social_linkedin_control',array(
        'type' => 'url',
		'section' => 'admania-footer-settings', 
		'label' => esc_html__('Linkedin url ','ad-mania'),
		'settings' => 'admania_ftrlinkedin',
		'description' => esc_html__('paste your linkedin url','ad-mania'),
	));
	
	$wp_customize->selective_refresh->add_partial('admania_ftrlinkedin', array(
       'selector' => '.admania-ftrattbtontop .admania-lnkflw', 
    ));
	
	$wp_customize->add_setting('admania_ftrpinterest',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_url',
	));
	
	$wp_customize->add_control('admania_footer_social_pin_control',array(
        'type' => 'url',
		'section' => 'admania-footer-settings', 
		'label' => esc_html__('Pinterest url','ad-mania'),
		'settings' => 'admania_ftrpinterest',
		'description' => esc_html__('paste your pinterest url','ad-mania'),
	));
	
	$wp_customize->selective_refresh->add_partial('admania_ftrpinterest', array(
       'selector' => '.admania-ftrattbtontop .admania-pinflw', 
    ));
	
	$wp_customize->add_setting('admania_ftrinstagram',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_url',
	));
	
	$wp_customize->add_control('admania_footer_social_ins_control',array(
        'type' => 'url',
		'section' => 'admania-footer-settings', 
		'label' => esc_html__('Instagram url ','ad-mania'),
		'settings' => 'admania_ftrinstagram',
		'description' => esc_html__('paste your instagram url','ad-mania'),
	));
	
	$wp_customize->selective_refresh->add_partial('admania_ftrinstagram', array(
       'selector' => '.admania-ftrattbtontop .admania-instgrmflw', 
    ));
	
	$wp_customize->add_setting('admania_ftrytub',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_url',
	));
	
	$wp_customize->add_control('admania_footer_social_yt_control',array(
        'type' => 'url',
		'section' => 'admania-footer-settings', 
		'label' => esc_html__('Youtube url ','ad-mania'),
		'settings' => 'admania_ftrytub',
		'description' => esc_html__('paste your youtube url','ad-mania'),
	));
	
	$wp_customize->add_setting('admania_ftrstumble',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_url',
	));
	
	$wp_customize->add_control('admania_footer_social_stmple_control',array(
        'type' => 'url',
		'section' => 'admania-footer-settings', 
		'label' => esc_html__('StumbleUpon url ','ad-mania'),
		'settings' => 'admania_ftrstumble',
		'description' => esc_html__('paste your StumbleUpon url','ad-mania'),
	));
	
	$wp_customize->selective_refresh->add_partial('admania_ftrstumble', array(
       'selector' => '.admania-ftrattbtontop .admania-stumbleflw', 
    ));
	
	$wp_customize->add_setting('admania_ftrredit',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_url',
	));
	
	$wp_customize->add_control('admania_footer_social_redit_control',array(
        'type' => 'url',
		'section' => 'admania-footer-settings', 
		'label' => esc_html__('Reddit url ','ad-mania'),
		'settings' => 'admania_ftrredit',
		'description' => esc_html__('paste your Reddit url','ad-mania'),
	));
	
	$wp_customize->selective_refresh->add_partial('admania_ftrredit', array(
       'selector' => '.admania-ftrattbtontop .admania-redditflw', 
    ));
	
	$wp_customize->add_setting('admania_ftrtg',array(
        'capability' => 'edit_theme_options',		
		'transport' => 'refresh',
        'sanitize_callback' => 'esc_url',
	));
	
	$wp_customize->add_control('admania_footer_social_telegrm_control',array(
        'type' => 'url',
		'section' => 'admania-footer-settings', 
		'label' => esc_html__('Telegram url ','ad-mania'),
		'settings' => 'admania_ftrtg',
		'description' => esc_html__('paste your telegram url','ad-mania'),
	));
	
	$wp_customize->selective_refresh->add_partial('admania_ftrtg', array(
       'selector' => '.admania-ftrattbtontop .admania-tgflw', 
    ));
	
	// Add theme color settings,section,control.
	
	$wp_customize->add_setting('backgroundcolor',array(
	   'default' => '#ffffff',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'backgroundcolor',array(
	  'section' => 'colors',
	  'label' => esc_html__('Body Background Color','ad-mania')	  
	)));	
	
	$wp_customize->add_setting('fontcolor',array(
	   'default' => '#282828',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'fontcolor',array(
	  'section' => 'colors',
	  'label' => esc_html__('Font Color','ad-mania')	  
	)));	
		
	$wp_customize->add_setting('admania_hdrtpbxclr',array(
	   'default' => '#e3e3e3',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_hdrtpbxclr',array(
	  'section' => 'colors',
	  'label' => esc_html__('Header Top Boxshawdow Color','ad-mania')	  
	)));
	
	$wp_customize->add_setting('admania_hdrtpbdrbtmclr',array(
	   'default' => '#dddddd',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_hdrtpbdrbtmclr',array(
	  'section' => 'colors',
	  'label' => esc_html__('Header Top BorderBottom Color','ad-mania')	  
	)));
	
	$wp_customize->add_setting('admania_hdrtpsclclr',array(
	   'default' => '#111111',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_hdrtpsclclr',array(
	  'section' => 'colors',
	  'label' => esc_html__('Header Top Social Follow Color','ad-mania')	  
	)));
	
	$wp_customize->add_setting('admania_hdrbtmbgclr',array(
	   'default' => '#222222',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_hdrbtmbgclr',array(
	  'section' => 'colors',
	  'label' => esc_html__('Header Bottom Background color','ad-mania')	  
	)));
	
	$wp_customize->add_setting('admania_mobilebgclr',array(
	   'default' => '#0592e0fc',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_mobilebgclr',array(
	  'section' => 'colors',
	  'label' => esc_html__('Mobile Menu Background color','ad-mania')	  
	)));
	
	$wp_customize->add_setting('admania_mobilebdrclr',array(
	   'default' => '#90bcd6',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_mobilebdrclr',array(
	  'section' => 'colors',
	  'label' => esc_html__('Mobile menu list border bottom color','ad-mania')	  
	)));
	
	$wp_customize->add_setting('admania_primarynavclr',array(
	   'default' => '#ffffff',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_primarynavclr',array(
	  'section' => 'colors',
	  'label' => esc_html__('Primary Nav Text color','ad-mania')	  
	)));
	
	$wp_customize->add_setting('admania_layt2navtxtcolor',array(
	   'default' => '#222222',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_layt2navtxtcolor',array(
	  'section' => 'colors',
	  'label' => esc_html__('Header Layout2 & Layout3 Primary Nav Text color','ad-mania')	  
	)));
	
	$wp_customize->add_setting('admania_bxdhdrbtmtxtclr',array(
	   'default' => '#7b7b7b',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_bxdhdrbtmtxtclr',array(
	  'section' => 'colors',
	  'label' => esc_html__('Boxed Header Bottom Text color','ad-mania')	  
	)));
	
	$wp_customize->add_setting('admania_srchtxtbgclr',array(
	   'default' => '#252424',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_srchtxtbgclr',array(
	  'section' => 'colors',
	  'label' => esc_html__('Header Search input text background color','ad-mania')	  
	)));
	
	$wp_customize->add_setting('admania_srchtxtclr',array(
	   'default' => '#ffffff',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_srchtxtclr',array(
	  'section' => 'colors',
	  'label' => esc_html__('Header Search Text Color','ad-mania')	  
	)));
	
	$wp_customize->add_setting('admania_layt3bgcolor',array(
	   'default' => '#1d1d1d',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_layt3bgcolor',array(
	  'section' => 'colors',
	  'label' => esc_html__('Layout3 & Layout5 Header Top Background Color','ad-mania')	  
	)));
	
	$wp_customize->add_setting('admania_layt3midbgcolor',array(
	   'default' => '#f7f7f7',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_layt3midbgcolor',array(
	  'section' => 'colors',
	  'label' => esc_html__('Header Bottom Background Color','ad-mania')	  
	)));
	
	$wp_customize->add_setting('admania_sldrhdclr',array(
	   'default' => '#ffffff',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_sldrhdclr',array(
	  'section' => 'colors',
	  'label' => esc_html__('Slider Heading & Content Color','ad-mania')	  
	)));
	
	$wp_customize->add_setting('admania-catbgclr',array(
	   'default' => '#ffffff',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania-catbgclr',array(
	  'section' => 'colors',
	  'label' => esc_html__('Category & Slider Next/prev Background Color','ad-mania')	  
	)));
	
	$wp_customize->add_setting('admania-cattxtclr',array(
	   'default' => '#111111',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania-cattxtclr',array(
	  'section' => 'colors',
	  'label' => esc_html__('Category Text Color','ad-mania')	  
	)));
	
	$wp_customize->add_setting('admania_linkclr',array(
	   'default' => '#858181',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_linkclr',array(
	  'section' => 'colors',
	  'label' => esc_html__('Link Color','ad-mania')	  
	)));
	
	$wp_customize->add_setting('admania_lnkhvclr',array(
	   'default' => '#47a7d7',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_lnkhvclr',array(
	  'section' => 'colors',
	  'label' => esc_html__('Link Hover Color','ad-mania')	  
	)));
	
	$wp_customize->add_setting('headerfontcolor',array(
	   'default' => '#222222',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'headerfontcolor',array(
	  'section' => 'colors',
	  'label' => esc_html__('All Heading Color','ad-mania')	  
	)));
	
	$wp_customize->add_setting('admania_thmebtnclr',array(
	   'default' => '#47a7d7',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_thmebtnclr',array(
	  'section' => 'colors',
	  'label' => esc_html__('Theme Button Background Color','ad-mania')	  
	)));
	
	$wp_customize->add_setting('admania_thmetxtbtnclr',array(
	   'default' => '#ffffff',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_thmetxtbtnclr',array(
	  'section' => 'colors',
	  'label' => esc_html__('Theme Button Color Text Color','ad-mania')	  
	)));
	 
	$wp_customize->add_setting('admania_thmebtnhvclr',array(
	   'default' => '#2a2a2a',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_thmebtnhvclr',array(
	  'section' => 'colors',
	  'label' => esc_html__('Theme Button Background Hover Color','ad-mania')	  
	)));
	
	$wp_customize->add_setting('admania_thmetxtbtnclr',array(
	   'default' => '#ffffff',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_thmetxtbtnclr',array(
	  'section' => 'colors',
	  'label' => esc_html__('Layout1 Theme Button Color Text Hover Color','ad-mania')	  
	)));
	 
	$wp_customize->add_setting('admania_thmecntrdbgclr',array(
	   'default' => '#f9f9f9',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_thmecntrdbgclr',array(
	  'section' => 'colors',
	  'label' => esc_html__('Layout1 Theme Continue Reading Background Color','ad-mania')	  
	))); 
	
	$wp_customize->add_setting('admania_thmecntrdtxtclr',array(
	   'default' => '#a59e9e',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_thmecntrdtxtclr',array(
	  'section' => 'colors',
	  'label' => esc_html__('Layout1 Theme Continue Reading Color Text Color','ad-mania')	  
	))); 	
	
	$wp_customize->add_setting('admania_thmecntrdbghvclr',array(
	   'default' => '#47a7d7',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_thmecntrdbghvclr',array(
	  'section' => 'colors',
	  'label' => esc_html__('Layout1 Theme Continue Reading & Slider prev/next Text Hover Color','ad-mania')	  
	))); 
	
	
	$wp_customize->add_setting('admania_layt3thmecntrdtxtclr',array(
	   'default' => '#ffffff',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_layt3thmecntrdtxtclr',array(
	  'section' => 'colors',
	  'label' => esc_html__('Layout3 Theme Continue Reading Color Text Color','ad-mania')	  
	))); 
	
	$wp_customize->add_setting('admania_layt5thmecntrdtxtclr',array(
	   'default' => '#ffffff',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_layt5thmecntrdtxtclr',array(
	  'section' => 'colors',
	  'label' => esc_html__('Layout5 Theme Continue Reading Color Text Color','ad-mania')	  
	))); 
	
	$wp_customize->add_setting('admania_layt5thmecntrdbgclr',array(
	   'default' => '#222222',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_layt5thmecntrdbgclr',array(
	  'section' => 'colors',
	  'label' => esc_html__('Layout5 Theme Continue Reading Background Color ','ad-mania')	  
	))); 
	
	
	$wp_customize->add_setting('admania_postcontentlinkcolor',array(
	   'default' => '#858181',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_postcontentlinkcolor',array(
	  'section' => 'colors',
	  'label' => esc_html__('Post Content link color','ad-mania')	  
	))); 
	
	$wp_customize->add_setting('admania_postoptintopbgcolor',array(
	   'default' => '#fbfbfb',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_postoptintopbgcolor',array(
	  'section' => 'colors',
	  'label' => esc_html__('Post Optin Background color','ad-mania')	  
	))); 
	
	
	$wp_customize->add_setting('admania_postoptintopbgbdrcolor',array(
	   'default' => '#eeeeee',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_postoptintopbgbdrcolor',array(
	  'section' => 'colors',
	  'label' => esc_html__('Post Optin Border color','ad-mania')	  
	))); 
	
	
	$wp_customize->add_setting('admania_pstcmtbgclr',array(
	   'default' => '#f7f7f7',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_pstcmtbgclr',array(
	  'section' => 'colors',
	  'label' => esc_html__('Comment Section Background color','ad-mania')	  
	))); 
	
	$wp_customize->add_setting('admania_pstcmtbgclr',array(
	   'default' => '#222222',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_pstcmtbgclr',array(
	  'section' => 'colors',
	  'label' => esc_html__('Footer Section Background color','ad-mania')	  
	))); 
	
	$wp_customize->add_setting('admania_ftrtextcolor',array(
	   'default' => '#858181',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_ftrtextcolor',array(
	  'section' => 'colors',
	  'label' => esc_html__('Footer Section text color','ad-mania')	  
	))); 
	
	$wp_customize->add_setting('admania_ftrwdgttitcolor',array(
	   'default' => '#ffffff',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_ftrwdgttitcolor',array(
	  'section' => 'colors',
	  'label' => esc_html__('Footer Section widget title color','ad-mania')	  
	))); 
		
	$wp_customize->add_setting('admania_ftrbdrcolor',array(
	   'default' => '#2d2d2d',
	   'transport' => 'refresh',
	   'sanitize_callback' => 'sanitize_hex_color'
	));
	
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize,'admania_ftrbdrcolor',array(
	  'section' => 'colors',
	  'label' => esc_html__('Footer Section border color','ad-mania')	  
	))); 
	
	
}

endif;

add_action( 'customize_register', 'admania_customize_register' );


/**
 * Render the site title for the selective refresh partial.
 *
 * @since admania 1.0
 * @see admania_customize_register()
 *
 * @return void
 */
if(! function_exists( 'admania_customize_partial_blogname' )):
function admania_customize_partial_blogname() {
	bloginfo( 'name' );
}
endif;
/**
 * Render the site tagline for the selective refresh partial.
 *
 * @since admania 1.0
 * @see admania_customize_register()
 *
 * @return void
 */
if(! function_exists( 'admania_customize_partial_blogdescription' )):
function admania_customize_partial_blogdescription() {
	bloginfo( 'description' );
}
endif;


/**
 * Render the site background color for the selective refresh partial.
 *
 * @since admania 1.0
 * @see admania_customize_register()
 *
 * @return void
 */
if(! function_exists( 'admania_customize_partial_background_color' )):
function admania_customize_partial_background_color() {
	echo sanitize_hex_color(get_theme_mod('background_color'));
}
endif;



/**
 * Render the latest post title text for the selective refresh partial.
 *
 * @since admania 1.0
 * @see admania_customize_register()
 *
 * @return void
 */
if(! function_exists( 'admania_latest_post_title_text' )):
function admania_latest_post_title_text() {
	echo esc_html(get_theme_mod('admania_latest_post_title_setting'));
}
endif;

/**
 * Render the header tp latest title text for the selective refresh partial.
 *
 * @since admania 1.0
 * @see admania_customize_register()
 *
 * @return void
 */
if(! function_exists( 'admania_header_tp_latest_text' )):
function admania_header_tp_latest_text() {
	echo esc_html(get_theme_mod('admania_header_tp_latest_text_setting'));
}
endif;


/**
 * Render the header10 tp offer bar text for the selective refresh partial.
 *
 * @since admania 1.0
 * @see admania_customize_register()
 *
 * @return void
 */
if(! function_exists( 'admania_header10_tp_offer_bar_text' )):
function admania_header10_tp_offer_bar_text() {
	echo esc_html(get_theme_mod('admania_header10_tp_offer_bar_text_setting'));
}
endif;

/**
 * Render the post content readmore text for the selective refresh partial.
 *
 * @since admania 1.0
 * @see admania_customize_register()
 *
 * @return void
 */
if(! function_exists( 'admania_post_content_readmore_text' )):
function admania_post_content_readmore_text() {
	echo esc_html(get_theme_mod('admania_post_read_more'));
}
endif;


/**
 * Render the header10 tp offer bar view more text for the selective refresh partial.
 *
 * @since admania 1.0
 * @see admania_customize_register()
 *
 * @return void
 */
if(! function_exists( 'admania_header10_tp_offer_bar_viewmore_text' )):
function admania_header10_tp_offer_bar_viewmore_text() {
	echo esc_html(get_theme_mod('admania_header10_tp_offer_bar_viewmore_text_setting'));
}
endif;


/**
 * Bind JS handlers to instantly live-preview changes.
 */
if(! function_exists( 'admania_customize_preview_scripts' )):
function admania_customize_preview_scripts() {	
    wp_enqueue_script( 'admania-customize-preview', get_theme_file_uri( '/lib/includes/admin/js/admania-customize-preview.js' ), array( 'customize-preview' ), '1.0', true );
    wp_enqueue_style( 'admania-customize-controls', get_theme_file_uri( '/lib/includes/admin/css/admania-customizer-controls.css'));
}
endif;
add_action( 'customize_preview_init', 'admania_customize_preview_scripts' );



/**
 * Load dynamic logic for the customizer controls area.
 */
if(! function_exists( 'admania_panels_scripts' )):
function admania_panels_scripts() {
	wp_enqueue_script( 'admania-customize-controls', get_theme_file_uri( '/lib/includes/admin/js/admania-customize-controls.js' ), array('customize-controls'), '1.0', true );
    wp_enqueue_style( 'admania-customize-controls', get_theme_file_uri( '/lib/includes/admin/css/admania-customizer-controls.css' ));
}
endif;
add_action( 'customize_controls_enqueue_scripts', 'admania_panels_scripts' );


if(class_exists('WP_Customize_Control')):
class admania_blog_layout_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand14';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Blog Layouts','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if(class_exists('WP_Customize_Control')):
class admania_input_layout_custom_control extends WP_Customize_Control {
  public $type = 'admania-custom-radio';
  public function render_content() {
	  $admania_blogscheme = array('amblyt1','amblyt2','amblyt3','amblyt4','amblyt5','amblyt6','amblyt7','amblyt8','amblyt9','amblyt10','amblyt11','amblyt12','amblyt13','amblyt14','amblyt15','amblyt16','amblyt17');
	  foreach ($admania_blogscheme as $admania_layvalue) { ?>
         <label class="customize-control-radio admania-layout-list" title="admania_layout"> 
			<img src="<?php echo esc_url( get_template_directory_uri()); ?>/lib/includes/images/<?php echo esc_html($admania_layvalue); ?>.jpg" alt="<?php esc_html_e('Layouts','ad-mania');?>">
            <input type="radio" <?php echo esc_attr($this->input_attrs()); ?> name ="_customize-<?php echo esc_attr($this->type); ?>-<?php echo esc_attr($this->id); ?>" class="admania_layout" id="<?php echo esc_attr($admania_layvalue); ?>" value="<?php echo esc_attr($admania_layvalue); ?>" <?php checked( get_theme_mod('admania_blog_layout_type') == $admania_layvalue ); ?> <?php echo esc_attr($this->link()); ?> />
         </label>
      <?php 
	  }    
  }
}
endif;


if(class_exists('WP_Customize_Control')):
class admania_header_input_layout_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-custom-radio';
  public function render_content() {
	  $admania_headerscheme = array('amheader1','amheader2','amheader3','amheader4','amheader5','amheader6','amheader7','amheader8','amheader9','amheader10','amheader11');
	  foreach ($admania_headerscheme as $admania_headertpvalue) { ?>
         <label class="customize-control-radio admania-layout-list" title="admania_headertypes"> 
			<img src="<?php echo esc_url( get_template_directory_uri()); ?>/lib/includes/images/<?php echo esc_html($admania_headertpvalue); ?>.jpg" alt="<?php esc_html_e('Layouts','ad-mania');?>">
            <input type="radio" <?php echo esc_attr($this->input_attrs()); ?> name ="_customize-<?php echo esc_attr($this->type); ?>-<?php echo esc_attr($this->id); ?>" class="admania_headertypes" id="<?php echo esc_attr($admania_headertpvalue); ?>" value="<?php echo esc_attr($admania_headertpvalue); ?>" <?php checked( get_theme_mod('admania_headertype_scheme') == $admania_headertpvalue ); ?> <?php echo esc_attr($this->link()); ?> />
         </label>
      <?php 
	  }    
  }
}
endif;


if(class_exists('WP_Customize_Control')):
class admania_post_input_layout_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-custom-radio';
  public function render_content() {
	  $admania_postblogscheme = array('amsplyt1','amsplyt2','amsplyt3','amsplyt4','amsplyt5','amsplyt6','amsplyt7');
	  foreach ($admania_postblogscheme as $admania_spbglayvalue) { ?>
         <label class="customize-control-radio admania-layout-list" title="admania_splayout"> 
			<img src="<?php echo esc_url( get_template_directory_uri()); ?>/lib/includes/images/<?php echo esc_html($admania_spbglayvalue); ?>.jpg" alt="<?php esc_html_e('Post Layouts','ad-mania');?>">
            <input type="radio" <?php echo esc_attr($this->input_attrs()); ?> name ="_customize-<?php echo esc_attr($this->type); ?>-<?php echo esc_attr($this->id); ?>" class="admania_splayout" id="<?php echo esc_attr($admania_spbglayvalue); ?>" value="<?php echo esc_attr($admania_spbglayvalue); ?>" <?php checked( get_theme_mod('admania_splyts_scheme') == $admania_spbglayvalue ); ?> <?php echo esc_attr($this->link()); ?> />
         </label>
      <?php 
	  }    
  }
}
endif;

if( class_exists('WP_Customize_Control')):
class admania_layout_width_option_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Layout Width Adjustment','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if( class_exists('WP_Customize_Control')):
class admania_header_sticky_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Sticky Header','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;


if( class_exists('WP_Customize_Control')):
class admania_header_tp_latest_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Header Top Latest Techonlogy','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;


if( class_exists('WP_Customize_Control')):
class admania_post_layout_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Post Layout','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if( class_exists('WP_Customize_Control')):
class admania_slider1_layout_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Home Page1 Slider','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if( class_exists('WP_Customize_Control')):
class admania_ftd_slider1_layout_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Home Page1 Featured Settings','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if( class_exists('WP_Customize_Control')):
class admania_ftd_slider2_layout_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Home Page2 Featured Settings','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if( class_exists('WP_Customize_Control')):
class admania_slider2_layout_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Home Page2 Slider','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if( class_exists('WP_Customize_Control')):
class admania_slider3_layout_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Home Page3 Slider','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if( class_exists('WP_Customize_Control')):
class admania_slider4_layout_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Home Page4 Slider','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if( class_exists('WP_Customize_Control')):
class admania_slider5_layout_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Home Page5 Slider','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if( class_exists('WP_Customize_Control')):
class admania_slider6_layout_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Home Page6 Slider','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if( class_exists('WP_Customize_Control')):
class admania_slider7_layout_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Mobile Slider','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if( class_exists('WP_Customize_Control')):
class admania_slider8_layout_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Woocommerce Slider','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if( class_exists('WP_Customize_Control')):
class admania_slider_note_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-note';
  public function render_content() {
    ?>
	<div class="admania-customizer-note">
	    <?php esc_html_e('please make sure to use the below options for slider only one option','ad-mania'); ?>
	</div>
	<?php
  }
}
endif;


if( class_exists('WP_Customize_Control')):
class admania_sidebar_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Customize the Sidebar','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;



if( class_exists('WP_Customize_Control')):
class admania_header10_tp_offer_bar_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Header10 Top Offer Bar','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if( class_exists('WP_Customize_Control')):
class admania_header_layout_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Headers Settings','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if( class_exists('WP_Customize_Control')):
class admania_header_social_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Header Social Media','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;


if(class_exists('WP_Customize_Control')):
class admania_header_search_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Header Search','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;


if(class_exists('WP_Customize_Control')):
class admania_responsive_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Responsive','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if(class_exists('WP_Customize_Control')):
class admania_latest_post_title_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Latest Post Title','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;


if(class_exists('WP_Customize_Control')):
class admania_header_script_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Header Script Code','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if(class_exists('WP_Customize_Control')):
class admania_footer_script_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Footer Script Code','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if(class_exists('WP_Customize_Control')):
class admania_adblocker_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Ad blocker','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if(class_exists('WP_Customize_Control')):
class admania_post_byline_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Post Byline','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;


if(class_exists('WP_Customize_Control')):
class admania_post_dft_ftdimg_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Post Default Featured Image','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;


if(class_exists('WP_Customize_Control')):
class admania_post_content_readmore_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Post Content Read More text','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;


if(class_exists('WP_Customize_Control')):
class admania_page_byline_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('By Line for Page','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;



if(class_exists('WP_Customize_Control')):
class admania_breadcrumb_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Breadcrumbs','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if(class_exists('WP_Customize_Control')):
class admania_post_socialshare_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Post Socialshare','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if(class_exists('WP_Customize_Control')):
class admania_home_socialshare_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Layout1,9 Home Post Social Share','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if(class_exists('WP_Customize_Control')):
class admania_relatedpost_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Related Post','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if(class_exists('WP_Customize_Control')):
class admania_pagination_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Pagination Settings','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if(class_exists('WP_Customize_Control')):
class admania_comment_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Comments','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;


//Custom control for google font 
if( class_exists( 'WP_Customize_Control' ) ):

class admania_google_font_dropdown_custom_control extends WP_Customize_Control{

public $type = 'admania-custom-select';

public function render_content(){
	
$admania_fontfamily = array('select','Arial','Arial, Helvetica, Sans-serif','Open Sans','Lora','Heebo','Abel','Averia Gruesa Libre','Artifika','Share Tech Mono','Alef','Anaheim','Allan','Advent Pro','Antic Slab','Alfa Slab One','Merriweather Serif','Amaranth','Alegreya Sans SC','ABeeZee','Armata','Abril Fatface','Anton','Alegreya','Amatic','Architects Daughter','Asap','Archivo Narrow','Cuprum','Crimson Text','Dancing Script','Raleway','Khula','Droid Sans','Droid Serif','Roboto','Roboto Condensed','Lato','Bree Serif','Oswald','Slabo','Lora','Source Sans Pro','PT Sans','Passion One','Cantarell','Englebert','Fenix','Simonetta','Voces','Cabin Condensed','Comfortaa','Ubuntu','Lobster','Arimo','Bitter','Noto Sans','Merriweather','Arimo','PT Sans Narrow','Hammersmith One','Titillium Web','PT Serif','Indie Flower','Arvo','Poiret One','Yanone Kaffeesatz','Playfair Display','Oxygen','Dosis','Cabin','Lobster','Fjalla One','Coda','Sacramento','Noto Serif','Hind','Inconsolata','Nunito','Muli','Metrophobic','Vollkorn','Signika','Delius','Josefin Sans','Ubuntu Condensed','Libre Baskerville','Fira Sans','Francois One','Shadows Into Light','Play','Ruluko','Londrina Solid','Tauri','Exo 2','Rationale','Rosarivo','Rubik','Ramabhadra','Maiden Orange','Sofia','Numans','Gabriela','Georgia,Serif','Sigmar One','Crushed','Tenor Sans','Pacifico','Orbitron','Quicksand','Monda','Rokkitt','Rosario','Candal','Yellowtail','Lemon','Montserrat','Varela Round','PT Sans Caption','Karla','Karma','Pathway Gothic One','Questrial','Righteous','Verdana','Patua One','Istok Web','Bangers','Josefin Slab','Source Code Pro','BenchNine','Gloria Hallelujah','Crete Round','Covered By Your Grace','EB Garamond','Ropa Sans','Noticia Text','Kaushan Script','Sintony','Playfair Display SC','Droid Sans Mono','Quattrocento Sans','Vidaloka','Patrick Hand SC','Poppins','Ovo','Lily Script One','Nova Square','Rufina','Imprima','Yantramanav','Nova Round','Palanquin','Laila','Fira Mono','Cagliostro','Nova Slim','McLaren','Paprika','Habibi','Helvetica','Overlock SC','Unkempt','Kelly Slab','Corben','Teko','Tahoma, Arial, Sans-serif','Tahoma','Bowlby One','Playball','Merienda','Caudex','Nobile','Cardo','Handlee','Economica','Changa One','Kreon','Bevan','Quattrocento','Alegreya Sans','Convergence','Rochester','Belleza','Allura','Montserrat Alternates','Sarala','PT Mono','Marcellus SC','Puritan','Port Lligat Slab','Forum','Baumans','Marcellus','Black Ops One','Podkova','Radley','Mako','Fanwood Text','Fontdiner Swanky','Rock Salt','Pinyon Script','Cherry Cream Soda','Reenie Beanie','Didact Gothic','Varela','Aldrich','Cinzel','Courgette','Voltaire','Andada','Russo One','Permanent Marker','Chewy','Denk One','Philosopher','Gudea','Sanchez','Chivo','Cutive Mono','Meddon','Gilda Display','Sniglet','Halant','Kotta One','Yeseva One','Old Standard TT','Sue Ellen Francisco','News Cycle','Knewave','Pontano Sans','Fredoka One','Archivo Black','Shadows Into Light Two','Lobster Two','Satisfy','Oxygen Mono','Unica One','Cousine','Duru Sans','Lustria','Coming Soon','Wire One','Gruppo','Tinos','Ruda','Slackey');

?>
<label class="customize_dropdown_input">
<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
<span class="description customize-control-description"><?php echo esc_html( $this->description ); ?></span>
<select id="<?php echo esc_attr($this->id); ?>" name="<?php echo esc_attr($this->id); ?>" <?php echo esc_attr($this->link()); ?>>
	<?php
	foreach ( $admania_fontfamily as $admania_fontvalue ){
		$admania_selected = (( $admania_fontvalue === get_theme_mod('admania_googlefont')) ? 'selected="selected"' : '');
	?>
		<option <?php echo esc_attr($admania_selected); ?>><?php echo esc_html(!empty($admania_fontvalue) ? $admania_fontvalue: ''); ?></option>
	<?php
	}
	?>
</select>
</label>
<?php
}
}
endif;

if(class_exists('WP_Customize_Control')):
class admania_input_range_custom_control extends WP_Customize_Control {
  public $type = 'admania-custom-range';
  public function render_content() {
    ?>
	   <label class="customize-control-range">
	 
            <?php if ( ! empty( $this->label )) : ?>
				<span class="customize-control-title"><?php echo esc_html($this->label); ?></span>
            <?php endif; ?>
			<?php if ( ! empty( $this->description )) : ?>
                <span class="description customize-control-description"><?php echo esc_html($this->description); ?></span>
            <?php endif; ?>
            <div class="admania-range-value"><?php echo esc_attr($this->value()); ?></div>
            <input data-input-type="range" type="range" <?php $this->input_attrs(); ?> value="<?php echo esc_attr($this->value()); ?>" <?php $this->link(); ?> />
            
        </label>
	<?php
  }
}
endif;


if(class_exists('WP_Customize_Control')):
class admania_google_heading_font_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('All Heading Google Font','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if(class_exists('WP_Customize_Control')):
class admania_body_font_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Body Font','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if(class_exists('WP_Customize_Control')):
class admania_h1_font_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('H1 Font','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if(class_exists('WP_Customize_Control')):
class admania_h2_font_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('H2 Font','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if(class_exists('WP_Customize_Control')):
class admania_h3_font_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('H3 Font','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if(class_exists('WP_Customize_Control')):
class admania_h4_font_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('H4 Font','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if(class_exists('WP_Customize_Control')):
class admania_h5_font_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('H5 Font','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if(class_exists('WP_Customize_Control')):
class admania_h6_font_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('H6 Font','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;


if(class_exists('WP_Customize_Control')):
class admania_google_body_font_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Site Body Google Font','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;


if(class_exists('WP_Customize_Control')):
class admania_newsletter_post_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Single Post Newsletter','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if(class_exists('WP_Customize_Control')):
class admania_mobile_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Mobile Settings','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

//Custom control for newsletter fields.

if( class_exists( 'WP_Customize_Control' ) ):

class admania_news_letter_custom_control extends WP_Customize_Control{

public $type = 'admania-custom-textarea';

public function render_content(){

?>

<label for="<?php echo esc_attr($this->id); ?>" class="customize-control-title">
		<?php echo esc_html( $this->label ); ?>
	  </label>
      <span id="<?php echo esc_attr($this->id); ?>" class="description customize-control-description"><?php echo esc_html( $this->description ); ?></span>
      <textarea id="<?php echo esc_attr($this->id); ?>" class="hidden13" rows="5" <?php $this->link(); ?>><?php echo wp_kses_stripslashes(get_theme_mod('admania_postoptincode')); ?></textarea>

<?php
}
}
endif;

//Custom control for newsletter fields.

if( class_exists( 'WP_Customize_Control' ) ):

class admania_nth_html_news_letter_custom_control extends WP_Customize_Control{

public $type = 'admania-custom-textarea';

public function render_content(){

?>
<label for="<?php echo esc_attr($this->id); ?>" class="customize-control-title">
    <?php echo esc_html( $this->label ); ?>
</label>
<span id="<?php echo esc_attr($this->id); ?>" class="description customize-control-description"><?php echo esc_html( $this->description ); ?></span>
<textarea id="<?php echo esc_attr($this->id); ?>" class="html13" rows="5" <?php $this->link(); ?>><?php echo wp_kses_stripslashes(get_theme_mod('admania_article_newsletter_html_setting')); ?></textarea>
<?php
}
}
endif;


// Custom Control for newsletter email.

if( class_exists('WP_Customize_Control')):

	class admania_post_news_letter_email_custom_control extends WP_Customize_Control {
		public $type = 'admania-custom-text';
		public function render_content() {
		?>
		<label for="<?php echo esc_attr($this->id); ?>" class="customize-control-title">
			<?php echo esc_attr($this->label); ?>
		</label>
		<span id="<?php echo esc_attr($this->id); ?>" class="description customize-control-description"><?php echo esc_html( $this->description ); ?></span>
		<input id="<?php echo esc_attr($this->id); ?>" class="email10" type="text" size="10" value="<?php echo (get_theme_mod('admania_postoptintypeemail')); ?>" <?php $this->link(); ?> />
		<?php
		}
	}
endif;

if( class_exists('WP_Customize_Control')):

	class admania_post_news_letter_name_custom_control extends WP_Customize_Control {
		public $type = 'admania-custom-text';
		public function render_content() {
		?>
		<label for="<?php echo esc_attr($this->id); ?>" class="customize-control-title">
			<?php echo esc_attr($this->label); ?>
		</label>
		<span id="<?php echo esc_attr($this->id); ?>" class="description customize-control-description"><?php echo esc_html( $this->description ); ?></span>
		<input id="<?php echo esc_attr($this->id); ?>" class="name10" type="text" size="10" value="<?php echo (get_theme_mod('admania_postoptintypename')); ?>" <?php $this->link(); ?> />
		<?php
		}
	}
endif;

// Custom Control for newsletter hidden.

if( class_exists('WP_Customize_Control')):
   class admania_news_letter_hidden_custom_control extends WP_Customize_Control {
      public $type = 'admania-custom-text';
	  public function render_content() {
	  ?>
	  <label for="<?php echo esc_attr($this->id); ?>" class="customize-control-title">
		<?php echo esc_html( $this->label ); ?>
	  </label>
	  <span id="<?php echo esc_attr($this->id); ?>" class="description customize-control-description"><?php echo esc_html( $this->description ); ?></span>
	  <textarea id="<?php echo esc_attr($this->id); ?>" class="html13" rows="5" cols="38" <?php $this->link(); ?>><?php echo wp_kses_stripslashes(get_theme_mod('admania_postoptintypehidden')); ?></textarea>
	  <?php
	  }
   }
endif;

// Custom Control for newsletter url.

if( class_exists('WP_Customize_Control')):
   class admania_news_letter_url_custom_control extends WP_Customize_Control {
      public $type = 'admania-custom-url';
	  public function render_content() {
	  ?>
	  <label for="<?php echo esc_attr($this->id); ?>" class="customize-control-title">
			<?php echo esc_attr($this->label); ?>
	  </label>
	  <span id="<?php echo esc_attr($this->id); ?>" class="description customize-control-description"><?php echo esc_html( $this->description ); ?></span>
	  <input id="<?php echo esc_attr($this->id); ?>" class="url10" type="url" size="10" value="<?php echo esc_url(get_theme_mod('admania_postoptintypeurl')); ?>" <?php $this->link(); ?>/>
	  <?php
	  }
   }
endif;





// Custom Control for newsletter email.

if( class_exists('WP_Customize_Control')):

	class admania_nth_post_news_letter_email_custom_control extends WP_Customize_Control {
		public $type = 'admania-custom-text';
		public function render_content() {
		?>
		<label for="<?php echo esc_attr($this->id); ?>" class="customize-control-title">
			<?php echo esc_attr($this->label); ?>
		</label>
		<span id="<?php echo esc_attr($this->id); ?>" class="description customize-control-description"><?php echo esc_html( $this->description ); ?></span>
		<input id="<?php echo esc_attr($this->id); ?>" class="email13" type="email" size="10" value="<?php echo (get_theme_mod('admania_article_newsletter_email')); ?>" <?php $this->link(); ?> />
		<?php
		}
	}
endif;


if( class_exists('WP_Customize_Control')):

	class admania_nth_post_news_letter_name_custom_control extends WP_Customize_Control {
		public $type = 'admania-custom-text';
		public function render_content() {
		?>
		<label for="<?php echo esc_attr($this->id); ?>" class="customize-control-title">
			<?php echo esc_attr($this->label); ?>
		</label>
		<span id="<?php echo esc_attr($this->id); ?>" class="description customize-control-description"><?php echo esc_html( $this->description ); ?></span>
		<input id="<?php echo esc_attr($this->id); ?>" class="name13" type="text" size="10" value="<?php echo esc_attr(get_theme_mod('admania_article_newsletter_name')); ?>" <?php $this->link(); ?>/>
		<?php
		}
	}
endif;

// Custom Control for newsletter hidden.

if( class_exists('WP_Customize_Control')):
   class admania_nth_news_letter_hidden_custom_control extends WP_Customize_Control {
      public $type = 'admania-custom-textarea';
	  public function render_content() {
	  ?>
	  <label for="<?php echo esc_attr($this->id); ?>" class="customize-control-title">
		<?php echo esc_html( $this->label ); ?>
	  </label>
      <span id="<?php echo esc_attr($this->id); ?>" class="description customize-control-description"><?php echo esc_html( $this->description ); ?></span>
      <textarea id="<?php echo esc_attr($this->id); ?>" class="hidden13" rows="5" <?php $this->link(); ?>><?php echo wp_kses_stripslashes(get_theme_mod('admania_article_newsletter_hidden_setting')); ?></textarea>
	  <?php
	  }
   }
endif;

// Custom Control for newsletter url.

if( class_exists('WP_Customize_Control')):
   class admania_nth_news_letter_url_custom_control extends WP_Customize_Control {
      public $type = 'admania-custom-url';
	  public function render_content() {
	  ?>
	  <label for="<?php echo esc_attr($this->id); ?>" class="customize-control-title">
			<?php echo esc_attr($this->label); ?>
	  </label>
	  <span id="<?php echo esc_attr($this->id); ?>" class="description customize-control-description"><?php echo esc_html( $this->description ); ?></span>
	  <input id="<?php echo esc_attr($this->id); ?>" class="url13" type="url" size="10" value="<?php echo get_theme_mod('admania_article_newsletter_url'); ?>" <?php $this->link(); ?>/>
	  <?php
	  }
   }
endif;

if(class_exists('WP_Customize_Control')):
class admania_nth_newsletter_post_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Nth Article Newsletter','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if(class_exists('WP_Customize_Control')):
class admania_instagram4_act_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Footer Settings','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if(class_exists('WP_Customize_Control')):
class admania_ftrcustomlogo_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Footer Custom Logo','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if(class_exists('WP_Customize_Control')):
class admania_footer_copyrights_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Footer Copyrighths Settings','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

if(class_exists('WP_Customize_Control')):
class admania_footer_social_expand_custom_control extends WP_Customize_Control {
  public $type = 'admania-themeoption-expand';
  public function render_content() {
    ?>
	<div class="admania-customizer-toggle">
	    <?php esc_html_e('Footer Social Follow Links','ad-mania'); ?>
		<span class="dashicons dashicons-arrow-down-alt2"></span>
	</div>
	<?php
  }
}
endif;

